Class: Aws::EMR::Types::AutoScalingPolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

An automatic scaling policy for a core instance group or task instance group in an Amazon EMR cluster. An automatic scaling policy defines how an instance group dynamically adds and terminates Amazon EC2 instances in response to the value of a CloudWatch metric. See PutAutoScalingPolicy.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#constraintsTypes::ScalingConstraints

The upper and lower Amazon EC2 instance limits for an automatic scaling policy. Automatic scaling activity will not cause an instance group to grow above or below these limits.



241
242
243
244
245
246
# File 'lib/aws-sdk-emr/types.rb', line 241

class AutoScalingPolicy < Struct.new(
  :constraints,
  :rules)
  SENSITIVE = []
  include Aws::Structure
end

#rulesArray<Types::ScalingRule>

The scale-in and scale-out rules that comprise the automatic scaling policy.

Returns:



241
242
243
244
245
246
# File 'lib/aws-sdk-emr/types.rb', line 241

class AutoScalingPolicy < Struct.new(
  :constraints,
  :rules)
  SENSITIVE = []
  include Aws::Structure
end