Class: Aws::EMR::Types::CertificateAuthority

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

Describes the certificate authority used to establish an mTLS connection to the Spark Connect server when connecting directly over VPC peering.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_arnString

The Amazon Resource Name (ARN) of the certificate authority in Amazon Web Services Private CA that issued the Spark Connect server certificate.

Returns:

  • (String)


526
527
528
529
530
531
# File 'lib/aws-sdk-emr/types.rb', line 526

class CertificateAuthority < Struct.new(
  :certificate_arn,
  :certificate_data)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_dataString

The PEM-encoded root CA certificate data. Provide this certificate to your client’s trust store when connecting directly to the Spark Connect server over VPC peering.

Returns:

  • (String)


526
527
528
529
530
531
# File 'lib/aws-sdk-emr/types.rb', line 526

class CertificateAuthority < Struct.new(
  :certificate_arn,
  :certificate_data)
  SENSITIVE = []
  include Aws::Structure
end