Class: Aws::EMR::Types::CreateSecurityConfigurationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::CreateSecurityConfigurationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the security configuration.
-
#security_configuration ⇒ String
The security configuration details in JSON format.
Instance Attribute Details
#name ⇒ String
The name of the security configuration.
1201 1202 1203 1204 1205 1206 |
# File 'lib/aws-sdk-emr/types.rb', line 1201 class CreateSecurityConfigurationInput < Struct.new( :name, :security_configuration) SENSITIVE = [] include Aws::Structure end |
#security_configuration ⇒ String
The security configuration details in JSON format. For JSON parameters and examples, see Use Security Configurations to Set Up Cluster Security in the Amazon EMR Management Guide.
1201 1202 1203 1204 1205 1206 |
# File 'lib/aws-sdk-emr/types.rb', line 1201 class CreateSecurityConfigurationInput < Struct.new( :name, :security_configuration) SENSITIVE = [] include Aws::Structure end |