Class: Aws::EMR::Types::DeleteStudioSessionMappingInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identity_idString

The globally unique identifier (GUID) of the user or group to remove from the Amazon EMR Studio. For more information, see UserId and GroupId in the IAM Identity Center Identity Store API Reference. Either IdentityName or IdentityId must be specified.

Returns:

  • (String)


1512
1513
1514
1515
1516
1517
1518
1519
# File 'lib/aws-sdk-emr/types.rb', line 1512

class DeleteStudioSessionMappingInput < Struct.new(
  :studio_id,
  :identity_id,
  :identity_name,
  :identity_type)
  SENSITIVE = []
  include Aws::Structure
end

#identity_nameString

The name of the user name or group to remove from the Amazon EMR Studio. For more information, see UserName and DisplayName in the IAM Identity Center Store API Reference. Either IdentityName or IdentityId must be specified.

Returns:

  • (String)


1512
1513
1514
1515
1516
1517
1518
1519
# File 'lib/aws-sdk-emr/types.rb', line 1512

class DeleteStudioSessionMappingInput < Struct.new(
  :studio_id,
  :identity_id,
  :identity_name,
  :identity_type)
  SENSITIVE = []
  include Aws::Structure
end

#identity_typeString

Specifies whether the identity to delete from the Amazon EMR Studio is a user or a group.

Returns:

  • (String)


1512
1513
1514
1515
1516
1517
1518
1519
# File 'lib/aws-sdk-emr/types.rb', line 1512

class DeleteStudioSessionMappingInput < Struct.new(
  :studio_id,
  :identity_id,
  :identity_name,
  :identity_type)
  SENSITIVE = []
  include Aws::Structure
end

#studio_idString

The ID of the Amazon EMR Studio.

Returns:

  • (String)


1512
1513
1514
1515
1516
1517
1518
1519
# File 'lib/aws-sdk-emr/types.rb', line 1512

class DeleteStudioSessionMappingInput < Struct.new(
  :studio_id,
  :identity_id,
  :identity_name,
  :identity_type)
  SENSITIVE = []
  include Aws::Structure
end