Class: Aws::EMR::Types::DescribeReleaseLabelOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#applicationsArray<Types::SimplifiedApplication>

The list of applications available for the target release label. Name is the name of the application. Version is the concise version of the application.

Returns:



1681
1682
1683
1684
1685
1686
1687
1688
# File 'lib/aws-sdk-emr/types.rb', line 1681

class DescribeReleaseLabelOutput < Struct.new(
  :release_label,
  :applications,
  :next_token,
  :available_os_releases)
  SENSITIVE = []
  include Aws::Structure
end

#available_os_releasesArray<Types::OSRelease>

The list of available Amazon Linux release versions for an Amazon EMR release. Contains a Label field that is formatted as shown in [ *Amazon Linux 2 Release Notes* ][1]. For example, [2.0.20220218.1].

[1]: docs.aws.amazon.com/AL2/latest/relnotes/relnotes-al2.html [2]: docs.aws.amazon.com/AL2/latest/relnotes/relnotes-20220218.html

Returns:



1681
1682
1683
1684
1685
1686
1687
1688
# File 'lib/aws-sdk-emr/types.rb', line 1681

class DescribeReleaseLabelOutput < Struct.new(
  :release_label,
  :applications,
  :next_token,
  :available_os_releases)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token. Reserved for future use. Currently set to null.

Returns:

  • (String)


1681
1682
1683
1684
1685
1686
1687
1688
# File 'lib/aws-sdk-emr/types.rb', line 1681

class DescribeReleaseLabelOutput < Struct.new(
  :release_label,
  :applications,
  :next_token,
  :available_os_releases)
  SENSITIVE = []
  include Aws::Structure
end

#release_labelString

The target release label described in the response.

Returns:

  • (String)


1681
1682
1683
1684
1685
1686
1687
1688
# File 'lib/aws-sdk-emr/types.rb', line 1681

class DescribeReleaseLabelOutput < Struct.new(
  :release_label,
  :applications,
  :next_token,
  :available_os_releases)
  SENSITIVE = []
  include Aws::Structure
end