Class: Aws::EMR::Types::ErrorDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::ErrorDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
A tuple that provides information about an error that caused a cluster to terminate.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_code ⇒ String
The name or code associated with the error.
-
#error_data ⇒ Array<Hash<String,String>>
A list of key value pairs that provides contextual information about why an error occured.
-
#error_message ⇒ String
A message that describes the error.
Instance Attribute Details
#error_code ⇒ String
The name or code associated with the error.
2031 2032 2033 2034 2035 2036 2037 |
# File 'lib/aws-sdk-emr/types.rb', line 2031 class ErrorDetail < Struct.new( :error_code, :error_data, :error_message) SENSITIVE = [] include Aws::Structure end |
#error_data ⇒ Array<Hash<String,String>>
A list of key value pairs that provides contextual information about why an error occured.
2031 2032 2033 2034 2035 2036 2037 |
# File 'lib/aws-sdk-emr/types.rb', line 2031 class ErrorDetail < Struct.new( :error_code, :error_data, :error_message) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
A message that describes the error.
2031 2032 2033 2034 2035 2036 2037 |
# File 'lib/aws-sdk-emr/types.rb', line 2031 class ErrorDetail < Struct.new( :error_code, :error_data, :error_message) SENSITIVE = [] include Aws::Structure end |