Class: Aws::EMR::Types::FailureDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::FailureDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
The details of the step failure. The service attempts to detect the root cause for many common failures.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_file ⇒ String
The path to the log file where the step failure root cause was originally recorded.
-
#message ⇒ String
The descriptive message including the error the Amazon EMR service has identified as the cause of step failure.
-
#reason ⇒ String
The reason for the step failure.
Instance Attribute Details
#log_file ⇒ String
The path to the log file where the step failure root cause was originally recorded.
2100 2101 2102 2103 2104 2105 2106 |
# File 'lib/aws-sdk-emr/types.rb', line 2100 class FailureDetails < Struct.new( :reason, :message, :log_file) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The descriptive message including the error the Amazon EMR service has identified as the cause of step failure. This is text from an error log that describes the root cause of the failure.
2100 2101 2102 2103 2104 2105 2106 |
# File 'lib/aws-sdk-emr/types.rb', line 2100 class FailureDetails < Struct.new( :reason, :message, :log_file) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The reason for the step failure. In the case where the service cannot successfully determine the root cause of the failure, it returns “Unknown Error” as a reason.
2100 2101 2102 2103 2104 2105 2106 |
# File 'lib/aws-sdk-emr/types.rb', line 2100 class FailureDetails < Struct.new( :reason, :message, :log_file) SENSITIVE = [] include Aws::Structure end |