Class: Aws::EMR::Types::GetSessionEndpointInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::GetSessionEndpointInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Input to the ‘GetSessionEndpoint` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
The ID of the cluster that the session belongs to.
-
#session_id ⇒ String
The ID of the session.
Instance Attribute Details
#cluster_id ⇒ String
The ID of the cluster that the session belongs to.
2365 2366 2367 2368 2369 2370 |
# File 'lib/aws-sdk-emr/types.rb', line 2365 class GetSessionEndpointInput < Struct.new( :cluster_id, :session_id) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The ID of the session.
2365 2366 2367 2368 2369 2370 |
# File 'lib/aws-sdk-emr/types.rb', line 2365 class GetSessionEndpointInput < Struct.new( :cluster_id, :session_id) SENSITIVE = [] include Aws::Structure end |