Class: Aws::EMR::Types::GetSessionEndpointOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

Output of the ‘GetSessionEndpoint` operation.

Constant Summary collapse

SENSITIVE =
[:auth_token]

Instance Attribute Summary collapse

Instance Attribute Details

#auth_tokenString

A time-limited authentication token used to connect to the Spark Connect endpoint.

Returns:

  • (String)


2395
2396
2397
2398
2399
2400
2401
2402
# File 'lib/aws-sdk-emr/types.rb', line 2395

class GetSessionEndpointOutput < Struct.new(
  :endpoint,
  :auth_token,
  :auth_token_expiration_time,
  :credentials)
  SENSITIVE = [:auth_token]
  include Aws::Structure
end

#auth_token_expiration_timeTime

The time at which the authentication token expires. After this time, call ‘GetSessionEndpoint` again to obtain a new token.

Returns:

  • (Time)


2395
2396
2397
2398
2399
2400
2401
2402
# File 'lib/aws-sdk-emr/types.rb', line 2395

class GetSessionEndpointOutput < Struct.new(
  :endpoint,
  :auth_token,
  :auth_token_expiration_time,
  :credentials)
  SENSITIVE = [:auth_token]
  include Aws::Structure
end

#credentialsTypes::Credentials

Username and password used to authenticate with the Spark Connect server when connecting directly over VPC peering.

Returns:



2395
2396
2397
2398
2399
2400
2401
2402
# File 'lib/aws-sdk-emr/types.rb', line 2395

class GetSessionEndpointOutput < Struct.new(
  :endpoint,
  :auth_token,
  :auth_token_expiration_time,
  :credentials)
  SENSITIVE = [:auth_token]
  include Aws::Structure
end

#endpointString

The Spark Connect endpoint URL to use in the PySpark client.

Returns:

  • (String)


2395
2396
2397
2398
2399
2400
2401
2402
# File 'lib/aws-sdk-emr/types.rb', line 2395

class GetSessionEndpointOutput < Struct.new(
  :endpoint,
  :auth_token,
  :auth_token_expiration_time,
  :credentials)
  SENSITIVE = [:auth_token]
  include Aws::Structure
end