Class: Aws::EMR::Types::GetSessionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::GetSessionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Input to the ‘GetSession` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
The ID of the cluster that the session belongs to.
-
#session_id ⇒ String
The ID of the session.
Instance Attribute Details
#cluster_id ⇒ String
The ID of the cluster that the session belongs to.
2416 2417 2418 2419 2420 2421 |
# File 'lib/aws-sdk-emr/types.rb', line 2416 class GetSessionInput < Struct.new( :cluster_id, :session_id) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The ID of the session.
2416 2417 2418 2419 2420 2421 |
# File 'lib/aws-sdk-emr/types.rb', line 2416 class GetSessionInput < Struct.new( :cluster_id, :session_id) SENSITIVE = [] include Aws::Structure end |