Class: Aws::EMR::Types::GetStudioSessionMappingInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::GetStudioSessionMappingInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identity_id ⇒ String
The globally unique identifier (GUID) of the user or group.
-
#identity_name ⇒ String
The name of the user or group to fetch.
-
#identity_type ⇒ String
Specifies whether the identity to fetch is a user or a group.
-
#studio_id ⇒ String
The ID of the Amazon EMR Studio.
Instance Attribute Details
#identity_id ⇒ String
2446 2447 2448 2449 2450 2451 2452 2453 |
# File 'lib/aws-sdk-emr/types.rb', line 2446 class GetStudioSessionMappingInput < Struct.new( :studio_id, :identity_id, :identity_name, :identity_type) SENSITIVE = [] include Aws::Structure end |
#identity_name ⇒ String
The name of the user or group to fetch. For more information, see
UserName and DisplayName in the IAM Identity Center
Identity Store API Reference. Either IdentityName or IdentityId
must be specified.
2446 2447 2448 2449 2450 2451 2452 2453 |
# File 'lib/aws-sdk-emr/types.rb', line 2446 class GetStudioSessionMappingInput < Struct.new( :studio_id, :identity_id, :identity_name, :identity_type) SENSITIVE = [] include Aws::Structure end |
#identity_type ⇒ String
Specifies whether the identity to fetch is a user or a group.
2446 2447 2448 2449 2450 2451 2452 2453 |
# File 'lib/aws-sdk-emr/types.rb', line 2446 class GetStudioSessionMappingInput < Struct.new( :studio_id, :identity_id, :identity_name, :identity_type) SENSITIVE = [] include Aws::Structure end |
#studio_id ⇒ String
The ID of the Amazon EMR Studio.
2446 2447 2448 2449 2450 2451 2452 2453 |
# File 'lib/aws-sdk-emr/types.rb', line 2446 class GetStudioSessionMappingInput < Struct.new( :studio_id, :identity_id, :identity_name, :identity_type) SENSITIVE = [] include Aws::Structure end |