Class: Aws::EMR::Types::Instance

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

Represents an Amazon EC2 instance provisioned as part of cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ebs_volumesArray<Types::EbsVolume>

The list of Amazon EBS volumes that are attached to this instance.



2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
# File 'lib/aws-sdk-emr/types.rb', line 2497

class Instance < Struct.new(
  :id,
  :ec2_instance_id,
  :public_dns_name,
  :public_ip_address,
  :private_dns_name,
  :private_ip_address,
  :status,
  :instance_group_id,
  :instance_fleet_id,
  :market,
  :instance_type,
  :ebs_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#ec2_instance_idString

The unique identifier of the instance in Amazon EC2.



2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
# File 'lib/aws-sdk-emr/types.rb', line 2497

class Instance < Struct.new(
  :id,
  :ec2_instance_id,
  :public_dns_name,
  :public_ip_address,
  :private_dns_name,
  :private_ip_address,
  :status,
  :instance_group_id,
  :instance_fleet_id,
  :market,
  :instance_type,
  :ebs_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier for the instance in Amazon EMR.



2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
# File 'lib/aws-sdk-emr/types.rb', line 2497

class Instance < Struct.new(
  :id,
  :ec2_instance_id,
  :public_dns_name,
  :public_ip_address,
  :private_dns_name,
  :private_ip_address,
  :status,
  :instance_group_id,
  :instance_fleet_id,
  :market,
  :instance_type,
  :ebs_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#instance_fleet_idString

The unique identifier of the instance fleet to which an Amazon EC2 instance belongs.



2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
# File 'lib/aws-sdk-emr/types.rb', line 2497

class Instance < Struct.new(
  :id,
  :ec2_instance_id,
  :public_dns_name,
  :public_ip_address,
  :private_dns_name,
  :private_ip_address,
  :status,
  :instance_group_id,
  :instance_fleet_id,
  :market,
  :instance_type,
  :ebs_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#instance_group_idString

The identifier of the instance group to which this instance belongs.



2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
# File 'lib/aws-sdk-emr/types.rb', line 2497

class Instance < Struct.new(
  :id,
  :ec2_instance_id,
  :public_dns_name,
  :public_ip_address,
  :private_dns_name,
  :private_ip_address,
  :status,
  :instance_group_id,
  :instance_fleet_id,
  :market,
  :instance_type,
  :ebs_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The Amazon EC2 instance type, for example m3.xlarge.



2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
# File 'lib/aws-sdk-emr/types.rb', line 2497

class Instance < Struct.new(
  :id,
  :ec2_instance_id,
  :public_dns_name,
  :public_ip_address,
  :private_dns_name,
  :private_ip_address,
  :status,
  :instance_group_id,
  :instance_fleet_id,
  :market,
  :instance_type,
  :ebs_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#marketString

The instance purchasing option. Valid values are ON_DEMAND or SPOT.



2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
# File 'lib/aws-sdk-emr/types.rb', line 2497

class Instance < Struct.new(
  :id,
  :ec2_instance_id,
  :public_dns_name,
  :public_ip_address,
  :private_dns_name,
  :private_ip_address,
  :status,
  :instance_group_id,
  :instance_fleet_id,
  :market,
  :instance_type,
  :ebs_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#private_dns_nameString

The private DNS name of the instance.



2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
# File 'lib/aws-sdk-emr/types.rb', line 2497

class Instance < Struct.new(
  :id,
  :ec2_instance_id,
  :public_dns_name,
  :public_ip_address,
  :private_dns_name,
  :private_ip_address,
  :status,
  :instance_group_id,
  :instance_fleet_id,
  :market,
  :instance_type,
  :ebs_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#private_ip_addressString

The private IP address of the instance.



2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
# File 'lib/aws-sdk-emr/types.rb', line 2497

class Instance < Struct.new(
  :id,
  :ec2_instance_id,
  :public_dns_name,
  :public_ip_address,
  :private_dns_name,
  :private_ip_address,
  :status,
  :instance_group_id,
  :instance_fleet_id,
  :market,
  :instance_type,
  :ebs_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#public_dns_nameString

The public DNS name of the instance.



2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
# File 'lib/aws-sdk-emr/types.rb', line 2497

class Instance < Struct.new(
  :id,
  :ec2_instance_id,
  :public_dns_name,
  :public_ip_address,
  :private_dns_name,
  :private_ip_address,
  :status,
  :instance_group_id,
  :instance_fleet_id,
  :market,
  :instance_type,
  :ebs_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#public_ip_addressString

The public IP address of the instance.



2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
# File 'lib/aws-sdk-emr/types.rb', line 2497

class Instance < Struct.new(
  :id,
  :ec2_instance_id,
  :public_dns_name,
  :public_ip_address,
  :private_dns_name,
  :private_ip_address,
  :status,
  :instance_group_id,
  :instance_fleet_id,
  :market,
  :instance_type,
  :ebs_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::InstanceStatus

The current status of the instance.



2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
# File 'lib/aws-sdk-emr/types.rb', line 2497

class Instance < Struct.new(
  :id,
  :ec2_instance_id,
  :public_dns_name,
  :public_ip_address,
  :private_dns_name,
  :private_ip_address,
  :status,
  :instance_group_id,
  :instance_fleet_id,
  :market,
  :instance_type,
  :ebs_volumes)
  SENSITIVE = []
  include Aws::Structure
end