Class: Aws::EMR::Types::InstanceFleetStateChangeReason

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

Provides status change reason details for the instance fleet.

The instance fleet configuration is available only in Amazon EMR releases 4.8.0 and later, excluding 5.0.x versions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

A code corresponding to the reason the state change occurred.

Returns:

  • (String)


2965
2966
2967
2968
2969
2970
# File 'lib/aws-sdk-emr/types.rb', line 2965

class InstanceFleetStateChangeReason < Struct.new(
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

An explanatory message.

Returns:

  • (String)


2965
2966
2967
2968
2969
2970
# File 'lib/aws-sdk-emr/types.rb', line 2965

class InstanceFleetStateChangeReason < Struct.new(
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end