Class: Aws::EMR::Types::InstanceGroupConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

Configuration defining a new instance group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_scaling_policyTypes::AutoScalingPolicy

An automatic scaling policy for a core instance group or task instance group in an Amazon EMR cluster. The automatic scaling policy defines how an instance group dynamically adds and terminates Amazon EC2 instances in response to the value of a CloudWatch metric. See PutAutoScalingPolicy.



3239
3240
3241
3242
3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
# File 'lib/aws-sdk-emr/types.rb', line 3239

class InstanceGroupConfig < Struct.new(
  :name,
  :market,
  :instance_role,
  :bid_price,
  :instance_type,
  :instance_count,
  :configurations,
  :ebs_configuration,
  :auto_scaling_policy,
  :custom_ami_id)
  SENSITIVE = []
  include Aws::Structure
end

#bid_priceString

The bid price for each Amazon EC2 Spot Instance type as defined by InstanceType. Expressed in USD. If neither BidPrice nor BidPriceAsPercentageOfOnDemandPrice is provided, BidPriceAsPercentageOfOnDemandPrice defaults to 100%.

Returns:

  • (String)


3239
3240
3241
3242
3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
# File 'lib/aws-sdk-emr/types.rb', line 3239

class InstanceGroupConfig < Struct.new(
  :name,
  :market,
  :instance_role,
  :bid_price,
  :instance_type,
  :instance_count,
  :configurations,
  :ebs_configuration,
  :auto_scaling_policy,
  :custom_ami_id)
  SENSITIVE = []
  include Aws::Structure
end

#configurationsArray<Types::Configuration>

Amazon EMR releases 4.x or later.

The list of configurations supplied for an Amazon EMR cluster instance group. You can specify a separate configuration for each instance group (master, core, and task).

Returns:



3239
3240
3241
3242
3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
# File 'lib/aws-sdk-emr/types.rb', line 3239

class InstanceGroupConfig < Struct.new(
  :name,
  :market,
  :instance_role,
  :bid_price,
  :instance_type,
  :instance_count,
  :configurations,
  :ebs_configuration,
  :auto_scaling_policy,
  :custom_ami_id)
  SENSITIVE = []
  include Aws::Structure
end

#custom_ami_idString

The custom AMI ID to use for the provisioned instance group.

Returns:

  • (String)


3239
3240
3241
3242
3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
# File 'lib/aws-sdk-emr/types.rb', line 3239

class InstanceGroupConfig < Struct.new(
  :name,
  :market,
  :instance_role,
  :bid_price,
  :instance_type,
  :instance_count,
  :configurations,
  :ebs_configuration,
  :auto_scaling_policy,
  :custom_ami_id)
  SENSITIVE = []
  include Aws::Structure
end

#ebs_configurationTypes::EbsConfiguration

EBS configurations that will be attached to each Amazon EC2 instance in the instance group.



3239
3240
3241
3242
3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
# File 'lib/aws-sdk-emr/types.rb', line 3239

class InstanceGroupConfig < Struct.new(
  :name,
  :market,
  :instance_role,
  :bid_price,
  :instance_type,
  :instance_count,
  :configurations,
  :ebs_configuration,
  :auto_scaling_policy,
  :custom_ami_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_countInteger

Target number of instances for the instance group.

Returns:

  • (Integer)


3239
3240
3241
3242
3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
# File 'lib/aws-sdk-emr/types.rb', line 3239

class InstanceGroupConfig < Struct.new(
  :name,
  :market,
  :instance_role,
  :bid_price,
  :instance_type,
  :instance_count,
  :configurations,
  :ebs_configuration,
  :auto_scaling_policy,
  :custom_ami_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_roleString

The role of the instance group in the cluster.

Returns:

  • (String)


3239
3240
3241
3242
3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
# File 'lib/aws-sdk-emr/types.rb', line 3239

class InstanceGroupConfig < Struct.new(
  :name,
  :market,
  :instance_role,
  :bid_price,
  :instance_type,
  :instance_count,
  :configurations,
  :ebs_configuration,
  :auto_scaling_policy,
  :custom_ami_id)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The Amazon EC2 instance type for all instances in the instance group.

Returns:

  • (String)


3239
3240
3241
3242
3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
# File 'lib/aws-sdk-emr/types.rb', line 3239

class InstanceGroupConfig < Struct.new(
  :name,
  :market,
  :instance_role,
  :bid_price,
  :instance_type,
  :instance_count,
  :configurations,
  :ebs_configuration,
  :auto_scaling_policy,
  :custom_ami_id)
  SENSITIVE = []
  include Aws::Structure
end

#marketString

Market type of the Amazon EC2 instances used to create a cluster node.

Returns:

  • (String)


3239
3240
3241
3242
3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
# File 'lib/aws-sdk-emr/types.rb', line 3239

class InstanceGroupConfig < Struct.new(
  :name,
  :market,
  :instance_role,
  :bid_price,
  :instance_type,
  :instance_count,
  :configurations,
  :ebs_configuration,
  :auto_scaling_policy,
  :custom_ami_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Friendly name given to the instance group.

Returns:

  • (String)


3239
3240
3241
3242
3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
# File 'lib/aws-sdk-emr/types.rb', line 3239

class InstanceGroupConfig < Struct.new(
  :name,
  :market,
  :instance_role,
  :bid_price,
  :instance_type,
  :instance_count,
  :configurations,
  :ebs_configuration,
  :auto_scaling_policy,
  :custom_ami_id)
  SENSITIVE = []
  include Aws::Structure
end