Class: Aws::EMR::Types::ListNotebookExecutionsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::ListNotebookExecutionsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
A pagination token that a subsequent
ListNotebookExecutionscan use to determine the next set of results to retrieve. -
#notebook_executions ⇒ Array<Types::NotebookExecutionSummary>
A list of notebook executions.
Instance Attribute Details
#marker ⇒ String
A pagination token that a subsequent ListNotebookExecutions can
use to determine the next set of results to retrieve.
4539 4540 4541 4542 4543 4544 |
# File 'lib/aws-sdk-emr/types.rb', line 4539 class ListNotebookExecutionsOutput < Struct.new( :notebook_executions, :marker) SENSITIVE = [] include Aws::Structure end |
#notebook_executions ⇒ Array<Types::NotebookExecutionSummary>
A list of notebook executions.
4539 4540 4541 4542 4543 4544 |
# File 'lib/aws-sdk-emr/types.rb', line 4539 class ListNotebookExecutionsOutput < Struct.new( :notebook_executions, :marker) SENSITIVE = [] include Aws::Structure end |