Class: Aws::EMR::Types::ListReleaseLabelsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::ListReleaseLabelsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Types::ReleaseLabelFilter
Filters the results of the request.
-
#max_results ⇒ Integer
Defines the maximum number of release labels to return in a single response.
-
#next_token ⇒ String
Specifies the next page of results.
Instance Attribute Details
#filters ⇒ Types::ReleaseLabelFilter
Filters the results of the request. Prefix specifies the prefix of
release labels to return. Application specifies the application
(with/without version) of release labels to return.
4570 4571 4572 4573 4574 4575 4576 |
# File 'lib/aws-sdk-emr/types.rb', line 4570 class ListReleaseLabelsInput < Struct.new( :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Defines the maximum number of release labels to return in a single
response. The default is 100.
4570 4571 4572 4573 4574 4575 4576 |
# File 'lib/aws-sdk-emr/types.rb', line 4570 class ListReleaseLabelsInput < Struct.new( :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies the next page of results. If NextToken is not specified,
which is usually the case for the first request of
ListReleaseLabels, the first page of results are determined by other
filtering parameters or by the latest version. The
ListReleaseLabels request fails if the identity (Amazon Web
Services account ID) and all filtering parameters are different from
the original request, or if the NextToken is expired or tampered
with.
4570 4571 4572 4573 4574 4575 4576 |
# File 'lib/aws-sdk-emr/types.rb', line 4570 class ListReleaseLabelsInput < Struct.new( :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |