Class: Aws::EMR::Types::ListSessionsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

Input to the ListSessions operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_idString

The ID of the cluster to list sessions for.

Returns:

  • (String)


4650
4651
4652
4653
4654
4655
4656
4657
# File 'lib/aws-sdk-emr/types.rb', line 4650

class ListSessionsInput < Struct.new(
  :cluster_id,
  :session_states,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of sessions to return in each page of results.

Returns:

  • (Integer)


4650
4651
4652
4653
4654
4655
4656
4657
# File 'lib/aws-sdk-emr/types.rb', line 4650

class ListSessionsInput < Struct.new(
  :cluster_id,
  :session_states,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token returned by a previous ListSessions call. Use it to retrieve the next page of results.

Returns:

  • (String)


4650
4651
4652
4653
4654
4655
4656
4657
# File 'lib/aws-sdk-emr/types.rb', line 4650

class ListSessionsInput < Struct.new(
  :cluster_id,
  :session_states,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#session_statesArray<String>

An optional filter that limits the results to sessions in the specified states.

Returns:

  • (Array<String>)


4650
4651
4652
4653
4654
4655
4656
4657
# File 'lib/aws-sdk-emr/types.rb', line 4650

class ListSessionsInput < Struct.new(
  :cluster_id,
  :session_states,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end