Class: Aws::EMR::Types::ListSessionsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

Output of the ListSessions operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The pagination token to use in a subsequent ListSessions call to retrieve the next page of results. This field is absent when there are no more results.

Returns:

  • (String)


4673
4674
4675
4676
4677
4678
# File 'lib/aws-sdk-emr/types.rb', line 4673

class ListSessionsOutput < Struct.new(
  :sessions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sessionsArray<Types::Session>

The sessions that match the request.

Returns:



4673
4674
4675
4676
4677
4678
# File 'lib/aws-sdk-emr/types.rb', line 4673

class ListSessionsOutput < Struct.new(
  :sessions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end