Class: Aws::EMR::Types::ListStudioSessionMappingsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::ListStudioSessionMappingsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identity_type ⇒ String
Specifies whether to return session mappings for users or groups.
-
#marker ⇒ String
The pagination token that indicates the set of results to retrieve.
-
#studio_id ⇒ String
The ID of the Amazon EMR Studio.
Instance Attribute Details
#identity_type ⇒ String
Specifies whether to return session mappings for users or groups. If not specified, the results include session mapping details for both users and groups.
4753 4754 4755 4756 4757 4758 4759 |
# File 'lib/aws-sdk-emr/types.rb', line 4753 class ListStudioSessionMappingsInput < Struct.new( :studio_id, :identity_type, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
The pagination token that indicates the set of results to retrieve.
4753 4754 4755 4756 4757 4758 4759 |
# File 'lib/aws-sdk-emr/types.rb', line 4753 class ListStudioSessionMappingsInput < Struct.new( :studio_id, :identity_type, :marker) SENSITIVE = [] include Aws::Structure end |
#studio_id ⇒ String
The ID of the Amazon EMR Studio.
4753 4754 4755 4756 4757 4758 4759 |
# File 'lib/aws-sdk-emr/types.rb', line 4753 class ListStudioSessionMappingsInput < Struct.new( :studio_id, :identity_type, :marker) SENSITIVE = [] include Aws::Structure end |