Class: Aws::EMR::Types::ListStudiosOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::ListStudiosOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
The pagination token that indicates the next set of results to retrieve.
-
#studios ⇒ Array<Types::StudioSummary>
The list of Studio summary objects.
Instance Attribute Details
#marker ⇒ String
The pagination token that indicates the next set of results to retrieve.
4657 4658 4659 4660 4661 4662 |
# File 'lib/aws-sdk-emr/types.rb', line 4657 class ListStudiosOutput < Struct.new( :studios, :marker) SENSITIVE = [] include Aws::Structure end |
#studios ⇒ Array<Types::StudioSummary>
The list of Studio summary objects.
4657 4658 4659 4660 4661 4662 |
# File 'lib/aws-sdk-emr/types.rb', line 4657 class ListStudiosOutput < Struct.new( :studios, :marker) SENSITIVE = [] include Aws::Structure end |