Class: Aws::EMR::Types::ModifyClusterInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_idString

The unique identifier of the cluster.

Returns:

  • (String)


4934
4935
4936
4937
4938
4939
4940
# File 'lib/aws-sdk-emr/types.rb', line 4934

class ModifyClusterInput < Struct.new(
  :cluster_id,
  :step_concurrency_level,
  :extended_support)
  SENSITIVE = []
  include Aws::Structure
end

#extended_supportBoolean

Reserved.

Returns:

  • (Boolean)


4934
4935
4936
4937
4938
4939
4940
# File 'lib/aws-sdk-emr/types.rb', line 4934

class ModifyClusterInput < Struct.new(
  :cluster_id,
  :step_concurrency_level,
  :extended_support)
  SENSITIVE = []
  include Aws::Structure
end

#step_concurrency_levelInteger

The number of steps that can be executed concurrently. You can specify a minimum of 1 step and a maximum of 256 steps. We recommend that you do not change this parameter while steps are running or the ActionOnFailure setting may not behave as expected. For more information see Step$ActionOnFailure.

Returns:

  • (Integer)


4934
4935
4936
4937
4938
4939
4940
# File 'lib/aws-sdk-emr/types.rb', line 4934

class ModifyClusterInput < Struct.new(
  :cluster_id,
  :step_concurrency_level,
  :extended_support)
  SENSITIVE = []
  include Aws::Structure
end