Class: Aws::EMR::Types::MonitoringConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

Contains CloudWatch log configuration and S3 logging configuration metadata and settings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_watch_log_configurationTypes::CloudWatchLogConfiguration

CloudWatch log configuration settings and metadata that specify settings like log files to monitor and where to send them.



4865
4866
4867
4868
4869
4870
# File 'lib/aws-sdk-emr/types.rb', line 4865

class MonitoringConfiguration < Struct.new(
  :cloud_watch_log_configuration,
  :s3_logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#s3_logging_configurationTypes::S3LoggingConfiguration

S3 logging configuration that controls how different types of logs (system logs, application logs, and persistent UI logs) are uploaded to S3. Each log type can be configured with a specific upload policy.



4865
4866
4867
4868
4869
4870
# File 'lib/aws-sdk-emr/types.rb', line 4865

class MonitoringConfiguration < Struct.new(
  :cloud_watch_log_configuration,
  :s3_logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end