Class: Aws::EMR::Types::NotebookExecution

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

A notebook execution. An execution is a specific instance that an Amazon EMR Notebook is run using the ‘StartNotebookExecution` action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the notebook execution.

Returns:

  • (String)


5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-emr/types.rb', line 5160

class NotebookExecution < Struct.new(
  :notebook_execution_id,
  :editor_id,
  :execution_engine,
  :notebook_execution_name,
  :notebook_params,
  :status,
  :start_time,
  :end_time,
  :arn,
  :output_notebook_uri,
  :last_state_change_reason,
  :notebook_instance_security_group_id,
  :tags,
  :notebook_s3_location,
  :output_notebook_s3_location,
  :output_notebook_format,
  :environment_variables)
  SENSITIVE = []
  include Aws::Structure
end

#editor_idString

The unique identifier of the Amazon EMR Notebook that is used for the notebook execution.

Returns:

  • (String)


5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-emr/types.rb', line 5160

class NotebookExecution < Struct.new(
  :notebook_execution_id,
  :editor_id,
  :execution_engine,
  :notebook_execution_name,
  :notebook_params,
  :status,
  :start_time,
  :end_time,
  :arn,
  :output_notebook_uri,
  :last_state_change_reason,
  :notebook_instance_security_group_id,
  :tags,
  :notebook_s3_location,
  :output_notebook_s3_location,
  :output_notebook_format,
  :environment_variables)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The timestamp when notebook execution ended.

Returns:

  • (Time)


5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-emr/types.rb', line 5160

class NotebookExecution < Struct.new(
  :notebook_execution_id,
  :editor_id,
  :execution_engine,
  :notebook_execution_name,
  :notebook_params,
  :status,
  :start_time,
  :end_time,
  :arn,
  :output_notebook_uri,
  :last_state_change_reason,
  :notebook_instance_security_group_id,
  :tags,
  :notebook_s3_location,
  :output_notebook_s3_location,
  :output_notebook_format,
  :environment_variables)
  SENSITIVE = []
  include Aws::Structure
end

#environment_variablesHash<String,String>

The environment variables associated with the notebook execution.

Returns:

  • (Hash<String,String>)


5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-emr/types.rb', line 5160

class NotebookExecution < Struct.new(
  :notebook_execution_id,
  :editor_id,
  :execution_engine,
  :notebook_execution_name,
  :notebook_params,
  :status,
  :start_time,
  :end_time,
  :arn,
  :output_notebook_uri,
  :last_state_change_reason,
  :notebook_instance_security_group_id,
  :tags,
  :notebook_s3_location,
  :output_notebook_s3_location,
  :output_notebook_format,
  :environment_variables)
  SENSITIVE = []
  include Aws::Structure
end

#execution_engineTypes::ExecutionEngineConfig

The execution engine, such as an Amazon EMR cluster, used to run the Amazon EMR notebook and perform the notebook execution.



5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-emr/types.rb', line 5160

class NotebookExecution < Struct.new(
  :notebook_execution_id,
  :editor_id,
  :execution_engine,
  :notebook_execution_name,
  :notebook_params,
  :status,
  :start_time,
  :end_time,
  :arn,
  :output_notebook_uri,
  :last_state_change_reason,
  :notebook_instance_security_group_id,
  :tags,
  :notebook_s3_location,
  :output_notebook_s3_location,
  :output_notebook_format,
  :environment_variables)
  SENSITIVE = []
  include Aws::Structure
end

#last_state_change_reasonString

The reason for the latest status change of the notebook execution.

Returns:

  • (String)


5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-emr/types.rb', line 5160

class NotebookExecution < Struct.new(
  :notebook_execution_id,
  :editor_id,
  :execution_engine,
  :notebook_execution_name,
  :notebook_params,
  :status,
  :start_time,
  :end_time,
  :arn,
  :output_notebook_uri,
  :last_state_change_reason,
  :notebook_instance_security_group_id,
  :tags,
  :notebook_s3_location,
  :output_notebook_s3_location,
  :output_notebook_format,
  :environment_variables)
  SENSITIVE = []
  include Aws::Structure
end

#notebook_execution_idString

The unique identifier of a notebook execution.

Returns:

  • (String)


5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-emr/types.rb', line 5160

class NotebookExecution < Struct.new(
  :notebook_execution_id,
  :editor_id,
  :execution_engine,
  :notebook_execution_name,
  :notebook_params,
  :status,
  :start_time,
  :end_time,
  :arn,
  :output_notebook_uri,
  :last_state_change_reason,
  :notebook_instance_security_group_id,
  :tags,
  :notebook_s3_location,
  :output_notebook_s3_location,
  :output_notebook_format,
  :environment_variables)
  SENSITIVE = []
  include Aws::Structure
end

#notebook_execution_nameString

A name for the notebook execution.

Returns:

  • (String)


5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-emr/types.rb', line 5160

class NotebookExecution < Struct.new(
  :notebook_execution_id,
  :editor_id,
  :execution_engine,
  :notebook_execution_name,
  :notebook_params,
  :status,
  :start_time,
  :end_time,
  :arn,
  :output_notebook_uri,
  :last_state_change_reason,
  :notebook_instance_security_group_id,
  :tags,
  :notebook_s3_location,
  :output_notebook_s3_location,
  :output_notebook_format,
  :environment_variables)
  SENSITIVE = []
  include Aws::Structure
end

#notebook_instance_security_group_idString

The unique identifier of the Amazon EC2 security group associated with the Amazon EMR Notebook instance. For more information see

Specifying Amazon EC2 Security Groups for Amazon EMR Notebooks][1

in the *Amazon EMR Management Guide*.

[1]: docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-security-groups.html

Returns:

  • (String)


5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-emr/types.rb', line 5160

class NotebookExecution < Struct.new(
  :notebook_execution_id,
  :editor_id,
  :execution_engine,
  :notebook_execution_name,
  :notebook_params,
  :status,
  :start_time,
  :end_time,
  :arn,
  :output_notebook_uri,
  :last_state_change_reason,
  :notebook_instance_security_group_id,
  :tags,
  :notebook_s3_location,
  :output_notebook_s3_location,
  :output_notebook_format,
  :environment_variables)
  SENSITIVE = []
  include Aws::Structure
end

#notebook_paramsString

Input parameters in JSON format passed to the Amazon EMR Notebook at runtime for execution.

Returns:

  • (String)


5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-emr/types.rb', line 5160

class NotebookExecution < Struct.new(
  :notebook_execution_id,
  :editor_id,
  :execution_engine,
  :notebook_execution_name,
  :notebook_params,
  :status,
  :start_time,
  :end_time,
  :arn,
  :output_notebook_uri,
  :last_state_change_reason,
  :notebook_instance_security_group_id,
  :tags,
  :notebook_s3_location,
  :output_notebook_s3_location,
  :output_notebook_format,
  :environment_variables)
  SENSITIVE = []
  include Aws::Structure
end

#notebook_s3_locationTypes::NotebookS3LocationForOutput

The Amazon S3 location that stores the notebook execution input.



5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-emr/types.rb', line 5160

class NotebookExecution < Struct.new(
  :notebook_execution_id,
  :editor_id,
  :execution_engine,
  :notebook_execution_name,
  :notebook_params,
  :status,
  :start_time,
  :end_time,
  :arn,
  :output_notebook_uri,
  :last_state_change_reason,
  :notebook_instance_security_group_id,
  :tags,
  :notebook_s3_location,
  :output_notebook_s3_location,
  :output_notebook_format,
  :environment_variables)
  SENSITIVE = []
  include Aws::Structure
end

#output_notebook_formatString

The output format for the notebook execution.

Returns:

  • (String)


5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-emr/types.rb', line 5160

class NotebookExecution < Struct.new(
  :notebook_execution_id,
  :editor_id,
  :execution_engine,
  :notebook_execution_name,
  :notebook_params,
  :status,
  :start_time,
  :end_time,
  :arn,
  :output_notebook_uri,
  :last_state_change_reason,
  :notebook_instance_security_group_id,
  :tags,
  :notebook_s3_location,
  :output_notebook_s3_location,
  :output_notebook_format,
  :environment_variables)
  SENSITIVE = []
  include Aws::Structure
end

#output_notebook_s3_locationTypes::OutputNotebookS3LocationForOutput

The Amazon S3 location for the notebook execution output.



5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-emr/types.rb', line 5160

class NotebookExecution < Struct.new(
  :notebook_execution_id,
  :editor_id,
  :execution_engine,
  :notebook_execution_name,
  :notebook_params,
  :status,
  :start_time,
  :end_time,
  :arn,
  :output_notebook_uri,
  :last_state_change_reason,
  :notebook_instance_security_group_id,
  :tags,
  :notebook_s3_location,
  :output_notebook_s3_location,
  :output_notebook_format,
  :environment_variables)
  SENSITIVE = []
  include Aws::Structure
end

#output_notebook_uriString

The location of the notebook execution’s output file in Amazon S3.

Returns:

  • (String)


5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-emr/types.rb', line 5160

class NotebookExecution < Struct.new(
  :notebook_execution_id,
  :editor_id,
  :execution_engine,
  :notebook_execution_name,
  :notebook_params,
  :status,
  :start_time,
  :end_time,
  :arn,
  :output_notebook_uri,
  :last_state_change_reason,
  :notebook_instance_security_group_id,
  :tags,
  :notebook_s3_location,
  :output_notebook_s3_location,
  :output_notebook_format,
  :environment_variables)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The timestamp when notebook execution started.

Returns:

  • (Time)


5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-emr/types.rb', line 5160

class NotebookExecution < Struct.new(
  :notebook_execution_id,
  :editor_id,
  :execution_engine,
  :notebook_execution_name,
  :notebook_params,
  :status,
  :start_time,
  :end_time,
  :arn,
  :output_notebook_uri,
  :last_state_change_reason,
  :notebook_instance_security_group_id,
  :tags,
  :notebook_s3_location,
  :output_notebook_s3_location,
  :output_notebook_format,
  :environment_variables)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the notebook execution.

  • ‘START_PENDING` indicates that the cluster has received the execution request but execution has not begun.

  • ‘STARTING` indicates that the execution is starting on the cluster.

  • ‘RUNNING` indicates that the execution is being processed by the cluster.

  • ‘FINISHING` indicates that execution processing is in the final stages.

  • ‘FINISHED` indicates that the execution has completed without error.

  • ‘FAILING` indicates that the execution is failing and will not finish successfully.

  • ‘FAILED` indicates that the execution failed.

  • ‘STOP_PENDING` indicates that the cluster has received a `StopNotebookExecution` request and the stop is pending.

  • ‘STOPPING` indicates that the cluster is in the process of stopping the execution as a result of a `StopNotebookExecution` request.

  • ‘STOPPED` indicates that the execution stopped because of a `StopNotebookExecution` request.

Returns:

  • (String)


5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-emr/types.rb', line 5160

class NotebookExecution < Struct.new(
  :notebook_execution_id,
  :editor_id,
  :execution_engine,
  :notebook_execution_name,
  :notebook_params,
  :status,
  :start_time,
  :end_time,
  :arn,
  :output_notebook_uri,
  :last_state_change_reason,
  :notebook_instance_security_group_id,
  :tags,
  :notebook_s3_location,
  :output_notebook_s3_location,
  :output_notebook_format,
  :environment_variables)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags associated with a notebook execution. Tags are user-defined key-value pairs that consist of a required key string with a maximum of 128 characters and an optional value string with a maximum of 256 characters.

Returns:



5160
5161
5162
5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-emr/types.rb', line 5160

class NotebookExecution < Struct.new(
  :notebook_execution_id,
  :editor_id,
  :execution_engine,
  :notebook_execution_name,
  :notebook_params,
  :status,
  :start_time,
  :end_time,
  :arn,
  :output_notebook_uri,
  :last_state_change_reason,
  :notebook_instance_security_group_id,
  :tags,
  :notebook_s3_location,
  :output_notebook_s3_location,
  :output_notebook_format,
  :environment_variables)
  SENSITIVE = []
  include Aws::Structure
end