Class: Aws::EMR::Types::OnDemandResizingSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

The resize specification for On-Demand Instances in the instance fleet, which contains the resize timeout period.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocation_strategyString

Specifies the allocation strategy to use to launch On-Demand instances during a resize. The default is lowest-price.

Returns:

  • (String)


5406
5407
5408
5409
5410
5411
5412
# File 'lib/aws-sdk-emr/types.rb', line 5406

class OnDemandResizingSpecification < Struct.new(
  :timeout_duration_minutes,
  :allocation_strategy,
  :capacity_reservation_options)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_reservation_optionsTypes::OnDemandCapacityReservationOptions

Describes the strategy for using unused Capacity Reservations for fulfilling On-Demand capacity.



5406
5407
5408
5409
5410
5411
5412
# File 'lib/aws-sdk-emr/types.rb', line 5406

class OnDemandResizingSpecification < Struct.new(
  :timeout_duration_minutes,
  :allocation_strategy,
  :capacity_reservation_options)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_duration_minutesInteger

On-Demand resize timeout in minutes. If On-Demand Instances are not provisioned within this time, the resize workflow stops. The minimum value is 5 minutes, and the maximum value is 10,080 minutes (7 days). The timeout applies to all resize workflows on the Instance Fleet. The resize could be triggered by Amazon EMR Managed Scaling or by the customer (via Amazon EMR Console, Amazon EMR CLI modify-instance-fleet or Amazon EMR SDK ModifyInstanceFleet API) or by Amazon EMR due to Amazon EC2 Spot Reclamation.

Returns:

  • (Integer)


5406
5407
5408
5409
5410
5411
5412
# File 'lib/aws-sdk-emr/types.rb', line 5406

class OnDemandResizingSpecification < Struct.new(
  :timeout_duration_minutes,
  :allocation_strategy,
  :capacity_reservation_options)
  SENSITIVE = []
  include Aws::Structure
end