Class: Aws::EMR::Types::PlacementGroupConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::PlacementGroupConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Placement group configuration for an Amazon EMR cluster. The configuration specifies the placement strategy that can be applied to instance roles during cluster creation.
To use this configuration, consider attaching managed policy AmazonElasticMapReducePlacementGroupPolicy to the Amazon EMR role.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_role ⇒ String
Role of the instance in the cluster.
-
#placement_strategy ⇒ String
Amazon EC2 Placement Group strategy associated with instance role.
Instance Attribute Details
#instance_role ⇒ String
Role of the instance in the cluster.
Starting with Amazon EMR release 5.23.0, the only supported instance role is ‘MASTER`.
5558 5559 5560 5561 5562 5563 |
# File 'lib/aws-sdk-emr/types.rb', line 5558 class PlacementGroupConfig < Struct.new( :instance_role, :placement_strategy) SENSITIVE = [] include Aws::Structure end |
#placement_strategy ⇒ String
Amazon EC2 Placement Group strategy associated with instance role.
Starting with Amazon EMR release 5.23.0, the only supported placement strategy is ‘SPREAD` for the `MASTER` instance role.
5558 5559 5560 5561 5562 5563 |
# File 'lib/aws-sdk-emr/types.rb', line 5558 class PlacementGroupConfig < Struct.new( :instance_role, :placement_strategy) SENSITIVE = [] include Aws::Structure end |