Class: Aws::EMR::Types::S3MonitoringConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::S3MonitoringConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
The Amazon S3 configuration for monitoring log publishing. You can configure your step to send log information to Amazon S3. When it's specified, it takes precedence over the cluster's logging configuration. If you don't specify this configuration entirely, or omit individual fields, EMR falls back to cluster-level logging behavior.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encryption_key_arn ⇒ String
The KMS key ARN to encrypt the logs published to the given Amazon S3 destination.
-
#log_uri ⇒ String
The Amazon S3 destination URI for log publishing.
Instance Attribute Details
#encryption_key_arn ⇒ String
The KMS key ARN to encrypt the logs published to the given Amazon S3 destination.
6276 6277 6278 6279 6280 6281 |
# File 'lib/aws-sdk-emr/types.rb', line 6276 class S3MonitoringConfiguration < Struct.new( :log_uri, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#log_uri ⇒ String
The Amazon S3 destination URI for log publishing.
6276 6277 6278 6279 6280 6281 |
# File 'lib/aws-sdk-emr/types.rb', line 6276 class S3MonitoringConfiguration < Struct.new( :log_uri, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |