Class: Aws::EMR::Types::ScalingRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::ScalingRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
A scale-in or scale-out rule that defines scaling activity, including the CloudWatch metric alarm that triggers activity, how Amazon EC2 instances are added or removed, and the periodicity of adjustments. The automatic scaling policy for an instance group can comprise one or more automatic scaling rules.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ Types::ScalingAction
The conditions that trigger an automatic scaling activity.
-
#description ⇒ String
A friendly, more verbose description of the automatic scaling rule.
-
#name ⇒ String
The name used to identify an automatic scaling rule.
-
#trigger ⇒ Types::ScalingTrigger
The CloudWatch alarm definition that determines when automatic scaling activity is triggered.
Instance Attribute Details
#action ⇒ Types::ScalingAction
The conditions that trigger an automatic scaling activity.
6357 6358 6359 6360 6361 6362 6363 6364 |
# File 'lib/aws-sdk-emr/types.rb', line 6357 class ScalingRule < Struct.new( :name, :description, :action, :trigger) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A friendly, more verbose description of the automatic scaling rule.
6357 6358 6359 6360 6361 6362 6363 6364 |
# File 'lib/aws-sdk-emr/types.rb', line 6357 class ScalingRule < Struct.new( :name, :description, :action, :trigger) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name used to identify an automatic scaling rule. Rule names must be unique within a scaling policy.
6357 6358 6359 6360 6361 6362 6363 6364 |
# File 'lib/aws-sdk-emr/types.rb', line 6357 class ScalingRule < Struct.new( :name, :description, :action, :trigger) SENSITIVE = [] include Aws::Structure end |
#trigger ⇒ Types::ScalingTrigger
The CloudWatch alarm definition that determines when automatic scaling activity is triggered.
6357 6358 6359 6360 6361 6362 6363 6364 |
# File 'lib/aws-sdk-emr/types.rb', line 6357 class ScalingRule < Struct.new( :name, :description, :action, :trigger) SENSITIVE = [] include Aws::Structure end |