Class: Aws::EMR::Types::SessionCloudWatchLoggingConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

The CloudWatch Logs configuration for a session.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

Whether CloudWatch Logs is enabled for the session.

Returns:

  • (Boolean)


6594
6595
6596
6597
6598
6599
6600
6601
6602
# File 'lib/aws-sdk-emr/types.rb', line 6594

class SessionCloudWatchLoggingConfiguration < Struct.new(
  :enabled,
  :log_group,
  :log_stream_name_prefix,
  :encryption_key_arn,
  :log_types)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_key_arnString

The Amazon Resource Name (ARN) of the KMS key used to encrypt the logs published to CloudWatch Logs.

Returns:

  • (String)


6594
6595
6596
6597
6598
6599
6600
6601
6602
# File 'lib/aws-sdk-emr/types.rb', line 6594

class SessionCloudWatchLoggingConfiguration < Struct.new(
  :enabled,
  :log_group,
  :log_stream_name_prefix,
  :encryption_key_arn,
  :log_types)
  SENSITIVE = []
  include Aws::Structure
end

#log_groupString

The name of the log group where session logs are published.

Returns:

  • (String)


6594
6595
6596
6597
6598
6599
6600
6601
6602
# File 'lib/aws-sdk-emr/types.rb', line 6594

class SessionCloudWatchLoggingConfiguration < Struct.new(
  :enabled,
  :log_group,
  :log_stream_name_prefix,
  :encryption_key_arn,
  :log_types)
  SENSITIVE = []
  include Aws::Structure
end

#log_stream_name_prefixString

The prefix applied to the log stream name where session logs are published.

Returns:

  • (String)


6594
6595
6596
6597
6598
6599
6600
6601
6602
# File 'lib/aws-sdk-emr/types.rb', line 6594

class SessionCloudWatchLoggingConfiguration < Struct.new(
  :enabled,
  :log_group,
  :log_stream_name_prefix,
  :encryption_key_arn,
  :log_types)
  SENSITIVE = []
  include Aws::Structure
end

#log_typesHash<String,Array<String>>

A map of log component names (for example, ‘SPARK_DRIVER`, `SPARK_EXECUTOR`) to the list of log types to publish for that component (for example, `stdout`, `stderr`).

Returns:

  • (Hash<String,Array<String>>)


6594
6595
6596
6597
6598
6599
6600
6601
6602
# File 'lib/aws-sdk-emr/types.rb', line 6594

class SessionCloudWatchLoggingConfiguration < Struct.new(
  :enabled,
  :log_group,
  :log_stream_name_prefix,
  :encryption_key_arn,
  :log_types)
  SENSITIVE = []
  include Aws::Structure
end