Class: Aws::EMR::Types::SessionMappingDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

Details for an Amazon EMR Studio session mapping including creation time, user or group ID, Studio ID, and so on.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The time the session mapping was created.

Returns:



6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
# File 'lib/aws-sdk-emr/types.rb', line 6302

class SessionMappingDetail < Struct.new(
  :studio_id,
  :identity_id,
  :identity_name,
  :identity_type,
  :session_policy_arn,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#identity_idString

The globally unique identifier (GUID) of the user or group.

Returns:



6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
# File 'lib/aws-sdk-emr/types.rb', line 6302

class SessionMappingDetail < Struct.new(
  :studio_id,
  :identity_id,
  :identity_name,
  :identity_type,
  :session_policy_arn,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#identity_nameString

The name of the user or group. For more information, see

UserName][1

and [DisplayName][2] in the *IAM Identity Center

Identity Store API Reference*.

[1]: docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_User.html#singlesignon-Type-User-UserName [2]: docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_Group.html#singlesignon-Type-Group-DisplayName

Returns:



6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
# File 'lib/aws-sdk-emr/types.rb', line 6302

class SessionMappingDetail < Struct.new(
  :studio_id,
  :identity_id,
  :identity_name,
  :identity_type,
  :session_policy_arn,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#identity_typeString

Specifies whether the identity mapped to the Amazon EMR Studio is a user or a group.

Returns:



6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
# File 'lib/aws-sdk-emr/types.rb', line 6302

class SessionMappingDetail < Struct.new(
  :studio_id,
  :identity_id,
  :identity_name,
  :identity_type,
  :session_policy_arn,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The time the session mapping was last modified.

Returns:



6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
# File 'lib/aws-sdk-emr/types.rb', line 6302

class SessionMappingDetail < Struct.new(
  :studio_id,
  :identity_id,
  :identity_name,
  :identity_type,
  :session_policy_arn,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#session_policy_arnString

The Amazon Resource Name (ARN) of the session policy associated with the user or group.

Returns:



6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
# File 'lib/aws-sdk-emr/types.rb', line 6302

class SessionMappingDetail < Struct.new(
  :studio_id,
  :identity_id,
  :identity_name,
  :identity_type,
  :session_policy_arn,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#studio_idString

The ID of the Amazon EMR Studio.

Returns:



6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
# File 'lib/aws-sdk-emr/types.rb', line 6302

class SessionMappingDetail < Struct.new(
  :studio_id,
  :identity_id,
  :identity_name,
  :identity_type,
  :session_policy_arn,
  :creation_time,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end