Class: Aws::EMR::Types::SessionS3LoggingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::SessionS3LoggingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
The Amazon S3 logging configuration for a session.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Whether Amazon S3 logging is enabled for the session.
-
#encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt logs published to Amazon S3.
-
#log_types ⇒ Hash<String,Array<String>>
A map of log component names (for example,
SPARK_DRIVER,SPARK_EXECUTOR) to the list of log types to publish for that component (for example,stdout,stderr). -
#log_uri ⇒ String
The Amazon S3 destination URI where session logs are published.
Instance Attribute Details
#enabled ⇒ Boolean
Whether Amazon S3 logging is enabled for the session.
6745 6746 6747 6748 6749 6750 6751 6752 |
# File 'lib/aws-sdk-emr/types.rb', line 6745 class SessionS3LoggingConfiguration < Struct.new( :enabled, :log_uri, :encryption_key_arn, :log_types) SENSITIVE = [] include Aws::Structure end |
#encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt logs published to Amazon S3.
6745 6746 6747 6748 6749 6750 6751 6752 |
# File 'lib/aws-sdk-emr/types.rb', line 6745 class SessionS3LoggingConfiguration < Struct.new( :enabled, :log_uri, :encryption_key_arn, :log_types) SENSITIVE = [] include Aws::Structure end |
#log_types ⇒ Hash<String,Array<String>>
A map of log component names (for example, SPARK_DRIVER,
SPARK_EXECUTOR) to the list of log types to publish for that
component (for example, stdout, stderr).
6745 6746 6747 6748 6749 6750 6751 6752 |
# File 'lib/aws-sdk-emr/types.rb', line 6745 class SessionS3LoggingConfiguration < Struct.new( :enabled, :log_uri, :encryption_key_arn, :log_types) SENSITIVE = [] include Aws::Structure end |
#log_uri ⇒ String
The Amazon S3 destination URI where session logs are published.
6745 6746 6747 6748 6749 6750 6751 6752 |
# File 'lib/aws-sdk-emr/types.rb', line 6745 class SessionS3LoggingConfiguration < Struct.new( :enabled, :log_uri, :encryption_key_arn, :log_types) SENSITIVE = [] include Aws::Structure end |