Class: Aws::EMR::Types::SetVisibleToAllUsersInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

The input to the SetVisibleToAllUsers action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_flow_idsArray<String>

The unique identifier of the job flow (cluster).

Returns:

  • (Array<String>)


6839
6840
6841
6842
6843
6844
# File 'lib/aws-sdk-emr/types.rb', line 6839

class SetVisibleToAllUsersInput < Struct.new(
  :job_flow_ids,
  :visible_to_all_users)
  SENSITIVE = []
  include Aws::Structure
end

#visible_to_all_usersBoolean

A value of true indicates that an IAM principal in the Amazon Web Services account can perform Amazon EMR actions on the cluster that the IAM policies attached to the principal allow. A value of false indicates that only the IAM principal that created the cluster and the Amazon Web Services root user can perform Amazon EMR actions on the cluster.

Returns:

  • (Boolean)


6839
6840
6841
6842
6843
6844
# File 'lib/aws-sdk-emr/types.rb', line 6839

class SetVisibleToAllUsersInput < Struct.new(
  :job_flow_ids,
  :visible_to_all_users)
  SENSITIVE = []
  include Aws::Structure
end