Class: Aws::EMR::Types::StartSessionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::StartSessionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Input to the StartSession operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_request_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#cluster_id ⇒ String
The ID of the cluster on which to start the session.
-
#engine_configurations ⇒ Array<Types::Configuration>
The configuration overrides for the session.
-
#execution_role_arn ⇒ String
The execution role ARN for the session.
-
#monitoring_configuration ⇒ Types::SessionMonitoringConfiguration
The monitoring configuration that controls where session logs are published, such as Amazon S3, CloudWatch, or managed logging.
-
#name ⇒ String
An optional name for the session.
-
#session_idle_timeout_in_minutes ⇒ Integer
The idle timeout, in minutes.
-
#tags ⇒ Array<Types::Tag>
The tags to assign to the session.
Instance Attribute Details
#client_request_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you retry a request that completed successfully using the same client request token, the service returns the original response without performing the operation again.
7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 |
# File 'lib/aws-sdk-emr/types.rb', line 7194 class StartSessionInput < Struct.new( :name, :cluster_id, :execution_role_arn, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |
#cluster_id ⇒ String
The ID of the cluster on which to start the session.
7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 |
# File 'lib/aws-sdk-emr/types.rb', line 7194 class StartSessionInput < Struct.new( :name, :cluster_id, :execution_role_arn, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |
#engine_configurations ⇒ Array<Types::Configuration>
The configuration overrides for the session. Only runtime configuration overrides are supported.
7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 |
# File 'lib/aws-sdk-emr/types.rb', line 7194 class StartSessionInput < Struct.new( :name, :cluster_id, :execution_role_arn, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The execution role ARN for the session. Amazon EMR uses this role to access Amazon Web Services resources on your behalf during session execution.
7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 |
# File 'lib/aws-sdk-emr/types.rb', line 7194 class StartSessionInput < Struct.new( :name, :cluster_id, :execution_role_arn, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |
#monitoring_configuration ⇒ Types::SessionMonitoringConfiguration
The monitoring configuration that controls where session logs are published, such as Amazon S3, CloudWatch, or managed logging.
7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 |
# File 'lib/aws-sdk-emr/types.rb', line 7194 class StartSessionInput < Struct.new( :name, :cluster_id, :execution_role_arn, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
An optional name for the session.
7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 |
# File 'lib/aws-sdk-emr/types.rb', line 7194 class StartSessionInput < Struct.new( :name, :cluster_id, :execution_role_arn, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |
#session_idle_timeout_in_minutes ⇒ Integer
The idle timeout, in minutes. If the session is idle for this duration, Amazon EMR EC2 automatically terminates it.
7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 |
# File 'lib/aws-sdk-emr/types.rb', line 7194 class StartSessionInput < Struct.new( :name, :cluster_id, :execution_role_arn, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to assign to the session.
7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 7205 |
# File 'lib/aws-sdk-emr/types.rb', line 7194 class StartSessionInput < Struct.new( :name, :cluster_id, :execution_role_arn, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :client_request_token, :tags) SENSITIVE = [] include Aws::Structure end |