Class: Aws::EMR::Types::StartSessionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::StartSessionOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Output of the StartSession operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Amazon Web Services account ID that owns the session.
-
#arn ⇒ String
The output contains the ARN of the session.
-
#cluster_id ⇒ String
The ID of the cluster that the session was started on.
-
#id ⇒ String
The output contains the ID of the session.
-
#state ⇒ String
The state of the session at the time the request returned.
Instance Attribute Details
#account_id ⇒ String
The Amazon Web Services account ID that owns the session.
7232 7233 7234 7235 7236 7237 7238 7239 7240 |
# File 'lib/aws-sdk-emr/types.rb', line 7232 class StartSessionOutput < Struct.new( :id, :cluster_id, :arn, :account_id, :state) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The output contains the ARN of the session.
7232 7233 7234 7235 7236 7237 7238 7239 7240 |
# File 'lib/aws-sdk-emr/types.rb', line 7232 class StartSessionOutput < Struct.new( :id, :cluster_id, :arn, :account_id, :state) SENSITIVE = [] include Aws::Structure end |
#cluster_id ⇒ String
The ID of the cluster that the session was started on.
7232 7233 7234 7235 7236 7237 7238 7239 7240 |
# File 'lib/aws-sdk-emr/types.rb', line 7232 class StartSessionOutput < Struct.new( :id, :cluster_id, :arn, :account_id, :state) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The output contains the ID of the session.
7232 7233 7234 7235 7236 7237 7238 7239 7240 |
# File 'lib/aws-sdk-emr/types.rb', line 7232 class StartSessionOutput < Struct.new( :id, :cluster_id, :arn, :account_id, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the session at the time the request returned. When a
session is first created, it enters the SUBMITTED state.
7232 7233 7234 7235 7236 7237 7238 7239 7240 |
# File 'lib/aws-sdk-emr/types.rb', line 7232 class StartSessionOutput < Struct.new( :id, :cluster_id, :arn, :account_id, :state) SENSITIVE = [] include Aws::Structure end |