Class: Aws::EMR::Types::StepStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::StepStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
The execution status details of the cluster step.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failure_details ⇒ Types::FailureDetails
The details for the step failure including reason, message, and log file path where the root cause was identified.
-
#state ⇒ String
The execution state of the cluster step.
-
#state_change_reason ⇒ Types::StepStateChangeReason
The reason for the step execution status change.
-
#timeline ⇒ Types::StepTimeline
The timeline of the cluster step status over time.
Instance Attribute Details
#failure_details ⇒ Types::FailureDetails
The details for the step failure including reason, message, and log file path where the root cause was identified.
7482 7483 7484 7485 7486 7487 7488 7489 |
# File 'lib/aws-sdk-emr/types.rb', line 7482 class StepStatus < Struct.new( :state, :state_change_reason, :failure_details, :timeline) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The execution state of the cluster step.
7482 7483 7484 7485 7486 7487 7488 7489 |
# File 'lib/aws-sdk-emr/types.rb', line 7482 class StepStatus < Struct.new( :state, :state_change_reason, :failure_details, :timeline) SENSITIVE = [] include Aws::Structure end |
#state_change_reason ⇒ Types::StepStateChangeReason
The reason for the step execution status change.
7482 7483 7484 7485 7486 7487 7488 7489 |
# File 'lib/aws-sdk-emr/types.rb', line 7482 class StepStatus < Struct.new( :state, :state_change_reason, :failure_details, :timeline) SENSITIVE = [] include Aws::Structure end |
#timeline ⇒ Types::StepTimeline
The timeline of the cluster step status over time.
7482 7483 7484 7485 7486 7487 7488 7489 |
# File 'lib/aws-sdk-emr/types.rb', line 7482 class StepStatus < Struct.new( :state, :state_change_reason, :failure_details, :timeline) SENSITIVE = [] include Aws::Structure end |