Class: Aws::EMR::Types::StepSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

The summary of the cluster step.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#action_on_failureString

The action to take when the cluster step fails. Possible values are TERMINATE_CLUSTER, CANCEL_AND_WAIT, and CONTINUE. TERMINATE_JOB_FLOW is available for backward compatibility.

Returns:

  • (String)


7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
# File 'lib/aws-sdk-emr/types.rb', line 7027

class StepSummary < Struct.new(
  :id,
  :name,
  :config,
  :action_on_failure,
  :status,
  :log_uri,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#configTypes::HadoopStepConfig

The Hadoop job configuration of the cluster step.



7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
# File 'lib/aws-sdk-emr/types.rb', line 7027

class StepSummary < Struct.new(
  :id,
  :name,
  :config,
  :action_on_failure,
  :status,
  :log_uri,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_key_arnString

The KMS key ARN to encrypt the logs published to the given Amazon S3 destination.

Returns:

  • (String)


7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
# File 'lib/aws-sdk-emr/types.rb', line 7027

class StepSummary < Struct.new(
  :id,
  :name,
  :config,
  :action_on_failure,
  :status,
  :log_uri,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the cluster step.

Returns:

  • (String)


7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
# File 'lib/aws-sdk-emr/types.rb', line 7027

class StepSummary < Struct.new(
  :id,
  :name,
  :config,
  :action_on_failure,
  :status,
  :log_uri,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#log_uriString

The Amazon S3 destination URI for log publishing.

Returns:

  • (String)


7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
# File 'lib/aws-sdk-emr/types.rb', line 7027

class StepSummary < Struct.new(
  :id,
  :name,
  :config,
  :action_on_failure,
  :status,
  :log_uri,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the cluster step.

Returns:

  • (String)


7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
# File 'lib/aws-sdk-emr/types.rb', line 7027

class StepSummary < Struct.new(
  :id,
  :name,
  :config,
  :action_on_failure,
  :status,
  :log_uri,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::StepStatus

The current execution status details of the cluster step.

Returns:



7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
# File 'lib/aws-sdk-emr/types.rb', line 7027

class StepSummary < Struct.new(
  :id,
  :name,
  :config,
  :action_on_failure,
  :status,
  :log_uri,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end