Class: Aws::EMR::Types::Studio
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::Studio
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Details for an Amazon EMR Studio including ID, creation time, name, and so on.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auth_mode ⇒ String
Specifies whether the Amazon EMR Studio authenticates users with IAM or IAM Identity Center.
-
#creation_time ⇒ Time
The time the Amazon EMR Studio was created.
-
#default_s3_location ⇒ String
The Amazon S3 location to back up Amazon EMR Studio Workspaces and notebook files.
-
#description ⇒ String
The detailed description of the Amazon EMR Studio.
-
#encryption_key_arn ⇒ String
The KMS key identifier (ARN) used to encrypt Amazon EMR Studio workspace and notebook files when backed up to Amazon S3.
-
#engine_security_group_id ⇒ String
The ID of the Engine security group associated with the Amazon EMR Studio.
-
#idc_instance_arn ⇒ String
The ARN of the IAM Identity Center instance the Studio application belongs to.
-
#idc_user_assignment ⇒ String
Indicates whether the Studio has
REQUIREDorOPTIONALIAM Identity Center user assignment. -
#idp_auth_url ⇒ String
Your identity provider’s authentication endpoint.
-
#idp_relay_state_parameter_name ⇒ String
The name of your identity provider’s
RelayStateparameter. -
#name ⇒ String
The name of the Amazon EMR Studio.
-
#service_role ⇒ String
The name of the IAM role assumed by the Amazon EMR Studio.
-
#studio_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon EMR Studio.
-
#studio_id ⇒ String
The ID of the Amazon EMR Studio.
-
#subnet_ids ⇒ Array<String>
The list of IDs of the subnets associated with the Amazon EMR Studio.
-
#tags ⇒ Array<Types::Tag>
A list of tags associated with the Amazon EMR Studio.
-
#trusted_identity_propagation_enabled ⇒ Boolean
Indicates whether the Studio has Trusted identity propagation enabled.
-
#url ⇒ String
The unique access URL of the Amazon EMR Studio.
-
#user_role ⇒ String
The name of the IAM role assumed by users logged in to the Amazon EMR Studio.
-
#vpc_id ⇒ String
The ID of the VPC associated with the Amazon EMR Studio.
-
#workspace_security_group_id ⇒ String
The ID of the Workspace security group associated with the Amazon EMR Studio.
Instance Attribute Details
#auth_mode ⇒ String
Specifies whether the Amazon EMR Studio authenticates users with IAM or IAM Identity Center.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time the Amazon EMR Studio was created.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#default_s3_location ⇒ String
The Amazon S3 location to back up Amazon EMR Studio Workspaces and notebook files.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The detailed description of the Amazon EMR Studio.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#encryption_key_arn ⇒ String
The KMS key identifier (ARN) used to encrypt Amazon EMR Studio workspace and notebook files when backed up to Amazon S3.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#engine_security_group_id ⇒ String
The ID of the Engine security group associated with the Amazon EMR Studio. The Engine security group allows inbound network traffic from resources in the Workspace security group.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#idc_instance_arn ⇒ String
The ARN of the IAM Identity Center instance the Studio application belongs to.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#idc_user_assignment ⇒ String
Indicates whether the Studio has REQUIRED or OPTIONAL IAM Identity Center user assignment. If the value is set to REQUIRED, users must be explicitly assigned to the Studio application to access the Studio.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#idp_auth_url ⇒ String
Your identity provider’s authentication endpoint. Amazon EMR Studio redirects federated users to this endpoint for authentication when logging in to a Studio with the Studio URL.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#idp_relay_state_parameter_name ⇒ String
The name of your identity provider’s RelayState parameter.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Amazon EMR Studio.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The name of the IAM role assumed by the Amazon EMR Studio.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#studio_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon EMR Studio.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#studio_id ⇒ String
The ID of the Amazon EMR Studio.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The list of IDs of the subnets associated with the Amazon EMR Studio.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags associated with the Amazon EMR Studio.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#trusted_identity_propagation_enabled ⇒ Boolean
Indicates whether the Studio has Trusted identity propagation enabled. The default value is false.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The unique access URL of the Amazon EMR Studio.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#user_role ⇒ String
The name of the IAM role assumed by users logged in to the Amazon EMR Studio. A Studio only requires a UserRole when you use IAM authentication.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC associated with the Amazon EMR Studio.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#workspace_security_group_id ⇒ String
The ID of the Workspace security group associated with the Amazon EMR Studio. The Workspace security group allows outbound network traffic to resources in the Engine security group and to the internet.
7199 7200 7201 7202 7203 7204 7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 7216 7217 7218 7219 7220 7221 7222 7223 |
# File 'lib/aws-sdk-emr/types.rb', line 7199 class Studio < Struct.new( :studio_id, :studio_arn, :name, :description, :auth_mode, :vpc_id, :subnet_ids, :service_role, :user_role, :workspace_security_group_id, :engine_security_group_id, :url, :creation_time, :default_s3_location, :idp_auth_url, :idp_relay_state_parameter_name, :tags, :idc_instance_arn, :trusted_identity_propagation_enabled, :idc_user_assignment, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |