Class: Aws::EMR::Types::SupportedInstanceType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

An instance type that the specified Amazon EMR release supports.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#architectureString

The CPU architecture, for example X86_64 or AARCH64.

Returns:

  • (String)


7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
# File 'lib/aws-sdk-emr/types.rb', line 7337

class SupportedInstanceType < Struct.new(
  :type,
  :memory_gb,
  :storage_gb,
  :vcpu,
  :is_64_bits_only,
  :instance_family_id,
  :ebs_optimized_available,
  :ebs_optimized_by_default,
  :number_of_disks,
  :ebs_storage_only,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#ebs_optimized_availableBoolean

Indicates whether the SupportedInstanceType supports Amazon EBS optimization.

Returns:

  • (Boolean)


7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
# File 'lib/aws-sdk-emr/types.rb', line 7337

class SupportedInstanceType < Struct.new(
  :type,
  :memory_gb,
  :storage_gb,
  :vcpu,
  :is_64_bits_only,
  :instance_family_id,
  :ebs_optimized_available,
  :ebs_optimized_by_default,
  :number_of_disks,
  :ebs_storage_only,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#ebs_optimized_by_defaultBoolean

Indicates whether the SupportedInstanceType uses Amazon EBS optimization by default.

Returns:

  • (Boolean)


7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
# File 'lib/aws-sdk-emr/types.rb', line 7337

class SupportedInstanceType < Struct.new(
  :type,
  :memory_gb,
  :storage_gb,
  :vcpu,
  :is_64_bits_only,
  :instance_family_id,
  :ebs_optimized_available,
  :ebs_optimized_by_default,
  :number_of_disks,
  :ebs_storage_only,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#ebs_storage_onlyBoolean

Indicates whether the SupportedInstanceType only supports Amazon EBS.

Returns:

  • (Boolean)


7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
# File 'lib/aws-sdk-emr/types.rb', line 7337

class SupportedInstanceType < Struct.new(
  :type,
  :memory_gb,
  :storage_gb,
  :vcpu,
  :is_64_bits_only,
  :instance_family_id,
  :ebs_optimized_available,
  :ebs_optimized_by_default,
  :number_of_disks,
  :ebs_storage_only,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#instance_family_idString

The Amazon EC2 family and generation for the SupportedInstanceType.

Returns:

  • (String)


7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
# File 'lib/aws-sdk-emr/types.rb', line 7337

class SupportedInstanceType < Struct.new(
  :type,
  :memory_gb,
  :storage_gb,
  :vcpu,
  :is_64_bits_only,
  :instance_family_id,
  :ebs_optimized_available,
  :ebs_optimized_by_default,
  :number_of_disks,
  :ebs_storage_only,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#is_64_bits_onlyBoolean

Indicates whether the SupportedInstanceType only supports 64-bit architecture.

Returns:

  • (Boolean)


7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
# File 'lib/aws-sdk-emr/types.rb', line 7337

class SupportedInstanceType < Struct.new(
  :type,
  :memory_gb,
  :storage_gb,
  :vcpu,
  :is_64_bits_only,
  :instance_family_id,
  :ebs_optimized_available,
  :ebs_optimized_by_default,
  :number_of_disks,
  :ebs_storage_only,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#memory_gbFloat

The amount of memory that is available to Amazon EMR from the SupportedInstanceType. The kernel and hypervisor software consume some memory, so this value might be lower than the overall memory for the instance type.

Returns:

  • (Float)


7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
# File 'lib/aws-sdk-emr/types.rb', line 7337

class SupportedInstanceType < Struct.new(
  :type,
  :memory_gb,
  :storage_gb,
  :vcpu,
  :is_64_bits_only,
  :instance_family_id,
  :ebs_optimized_available,
  :ebs_optimized_by_default,
  :number_of_disks,
  :ebs_storage_only,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_disksInteger

Number of disks for the SupportedInstanceType. This value is 0 for Amazon EBS-only instance types.

Returns:

  • (Integer)


7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
# File 'lib/aws-sdk-emr/types.rb', line 7337

class SupportedInstanceType < Struct.new(
  :type,
  :memory_gb,
  :storage_gb,
  :vcpu,
  :is_64_bits_only,
  :instance_family_id,
  :ebs_optimized_available,
  :ebs_optimized_by_default,
  :number_of_disks,
  :ebs_storage_only,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#storage_gbInteger

StorageGB represents the storage capacity of the SupportedInstanceType. This value is 0 for Amazon EBS-only instance types.

Returns:

  • (Integer)


7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
# File 'lib/aws-sdk-emr/types.rb', line 7337

class SupportedInstanceType < Struct.new(
  :type,
  :memory_gb,
  :storage_gb,
  :vcpu,
  :is_64_bits_only,
  :instance_family_id,
  :ebs_optimized_available,
  :ebs_optimized_by_default,
  :number_of_disks,
  :ebs_storage_only,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The [Amazon EC2 instance type][1], for example m5.xlarge, of the SupportedInstanceType.

[1]: aws.amazon.com/ec2/instance-types/

Returns:

  • (String)


7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
# File 'lib/aws-sdk-emr/types.rb', line 7337

class SupportedInstanceType < Struct.new(
  :type,
  :memory_gb,
  :storage_gb,
  :vcpu,
  :is_64_bits_only,
  :instance_family_id,
  :ebs_optimized_available,
  :ebs_optimized_by_default,
  :number_of_disks,
  :ebs_storage_only,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end

#vcpuInteger

The number of vCPUs available for the SupportedInstanceType.

Returns:

  • (Integer)


7337
7338
7339
7340
7341
7342
7343
7344
7345
7346
7347
7348
7349
7350
7351
# File 'lib/aws-sdk-emr/types.rb', line 7337

class SupportedInstanceType < Struct.new(
  :type,
  :memory_gb,
  :storage_gb,
  :vcpu,
  :is_64_bits_only,
  :instance_family_id,
  :ebs_optimized_available,
  :ebs_optimized_by_default,
  :number_of_disks,
  :ebs_storage_only,
  :architecture)
  SENSITIVE = []
  include Aws::Structure
end