Class: Aws::EMR::Types::TerminateSessionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::TerminateSessionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Input to the ‘TerminateSession` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
The ID of the cluster that the session belongs to.
-
#session_id ⇒ String
The ID of the session to terminate.
Instance Attribute Details
#cluster_id ⇒ String
The ID of the cluster that the session belongs to.
7951 7952 7953 7954 7955 7956 |
# File 'lib/aws-sdk-emr/types.rb', line 7951 class TerminateSessionInput < Struct.new( :cluster_id, :session_id) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The ID of the session to terminate.
7951 7952 7953 7954 7955 7956 |
# File 'lib/aws-sdk-emr/types.rb', line 7951 class TerminateSessionInput < Struct.new( :cluster_id, :session_id) SENSITIVE = [] include Aws::Structure end |