Class: Aws::EMR::Types::UpdateStudioInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_s3_locationString

The Amazon S3 location to back up Workspaces and notebook files for the Amazon EMR Studio.

Returns:

  • (String)


7984
7985
7986
7987
7988
7989
7990
7991
7992
7993
# File 'lib/aws-sdk-emr/types.rb', line 7984

class UpdateStudioInput < Struct.new(
  :studio_id,
  :name,
  :description,
  :subnet_ids,
  :default_s3_location,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A detailed description to assign to the Amazon EMR Studio.

Returns:

  • (String)


7984
7985
7986
7987
7988
7989
7990
7991
7992
7993
# File 'lib/aws-sdk-emr/types.rb', line 7984

class UpdateStudioInput < Struct.new(
  :studio_id,
  :name,
  :description,
  :subnet_ids,
  :default_s3_location,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_key_arnString

The KMS key identifier (ARN) used to encrypt Amazon EMR Studio workspace and notebook files when backed up to Amazon S3.

Returns:

  • (String)


7984
7985
7986
7987
7988
7989
7990
7991
7992
7993
# File 'lib/aws-sdk-emr/types.rb', line 7984

class UpdateStudioInput < Struct.new(
  :studio_id,
  :name,
  :description,
  :subnet_ids,
  :default_s3_location,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A descriptive name for the Amazon EMR Studio.

Returns:

  • (String)


7984
7985
7986
7987
7988
7989
7990
7991
7992
7993
# File 'lib/aws-sdk-emr/types.rb', line 7984

class UpdateStudioInput < Struct.new(
  :studio_id,
  :name,
  :description,
  :subnet_ids,
  :default_s3_location,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#studio_idString

The ID of the Amazon EMR Studio to update.

Returns:

  • (String)


7984
7985
7986
7987
7988
7989
7990
7991
7992
7993
# File 'lib/aws-sdk-emr/types.rb', line 7984

class UpdateStudioInput < Struct.new(
  :studio_id,
  :name,
  :description,
  :subnet_ids,
  :default_s3_location,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

A list of subnet IDs to associate with the Amazon EMR Studio. The list can include new subnet IDs, but must also include all of the subnet IDs previously associated with the Studio. The list order does not matter. A Studio can have a maximum of 5 subnets. The subnets must belong to the same VPC as the Studio.

Returns:

  • (Array<String>)


7984
7985
7986
7987
7988
7989
7990
7991
7992
7993
# File 'lib/aws-sdk-emr/types.rb', line 7984

class UpdateStudioInput < Struct.new(
  :studio_id,
  :name,
  :description,
  :subnet_ids,
  :default_s3_location,
  :encryption_key_arn)
  SENSITIVE = []
  include Aws::Structure
end