Class: Aws::EMR::Types::UpdateStudioSessionMappingInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identity_idString

The globally unique identifier (GUID) of the user or group. For more information, see UserId and GroupId in the IAM Identity Center Identity Store API Reference. Either IdentityName or IdentityId must be specified.

Returns:

  • (String)


8034
8035
8036
8037
8038
8039
8040
8041
8042
# File 'lib/aws-sdk-emr/types.rb', line 8034

class UpdateStudioSessionMappingInput < Struct.new(
  :studio_id,
  :identity_id,
  :identity_name,
  :identity_type,
  :session_policy_arn)
  SENSITIVE = []
  include Aws::Structure
end

#identity_nameString

The name of the user or group to update. For more information, see UserName and DisplayName in the IAM Identity Center Identity Store API Reference. Either IdentityName or IdentityId must be specified.

Returns:

  • (String)


8034
8035
8036
8037
8038
8039
8040
8041
8042
# File 'lib/aws-sdk-emr/types.rb', line 8034

class UpdateStudioSessionMappingInput < Struct.new(
  :studio_id,
  :identity_id,
  :identity_name,
  :identity_type,
  :session_policy_arn)
  SENSITIVE = []
  include Aws::Structure
end

#identity_typeString

Specifies whether the identity to update is a user or a group.

Returns:

  • (String)


8034
8035
8036
8037
8038
8039
8040
8041
8042
# File 'lib/aws-sdk-emr/types.rb', line 8034

class UpdateStudioSessionMappingInput < Struct.new(
  :studio_id,
  :identity_id,
  :identity_name,
  :identity_type,
  :session_policy_arn)
  SENSITIVE = []
  include Aws::Structure
end

#session_policy_arnString

The Amazon Resource Name (ARN) of the session policy to associate with the specified user or group.

Returns:

  • (String)


8034
8035
8036
8037
8038
8039
8040
8041
8042
# File 'lib/aws-sdk-emr/types.rb', line 8034

class UpdateStudioSessionMappingInput < Struct.new(
  :studio_id,
  :identity_id,
  :identity_name,
  :identity_type,
  :session_policy_arn)
  SENSITIVE = []
  include Aws::Structure
end

#studio_idString

The ID of the Amazon EMR Studio.

Returns:

  • (String)


8034
8035
8036
8037
8038
8039
8040
8041
8042
# File 'lib/aws-sdk-emr/types.rb', line 8034

class UpdateStudioSessionMappingInput < Struct.new(
  :studio_id,
  :identity_id,
  :identity_name,
  :identity_type,
  :session_policy_arn)
  SENSITIVE = []
  include Aws::Structure
end