Class: Aws::EMR::Waiters::ClusterRunning
- Inherits:
-
Object
- Object
- Aws::EMR::Waiters::ClusterRunning
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-emr/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ClusterRunning
constructor
A new instance of ClusterRunning.
-
#wait(params = {}) ⇒ Types::DescribeClusterOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ClusterRunning
Returns a new instance of ClusterRunning.
86 87 |
# File 'lib/aws-sdk-emr/waiters.rb', line 86
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
136 137 138 |
# File 'lib/aws-sdk-emr/waiters.rb', line 136 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeClusterOutput
Returns a response object which responds to the following methods:
- #cluster => Types::Cluster
131 |
# File 'lib/aws-sdk-emr/waiters.rb', line 131
def wait: (
|