Class: Aws::EMR::Waiters::StepComplete

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-emr/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ StepComplete

Returns a new instance of StepComplete.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 30
  • :before_attempt (Proc)
  • :before_wait (Proc)


192
193
# File 'lib/aws-sdk-emr/waiters.rb', line 192

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



230
231
232
# File 'lib/aws-sdk-emr/waiters.rb', line 230

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeStepOutput

Returns a response object which responds to the following methods:

Options Hash (params):

  • :cluster_id (required, String)

    The identifier of the cluster with steps to describe.

  • :step_id (required, String)

    The identifier of the step to describe.

Returns:



225
# File 'lib/aws-sdk-emr/waiters.rb', line 225

def wait: (