Class: Aws::EMR::Types::CertificateAuthority
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::CertificateAuthority
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Describes the certificate authority used to establish an mTLS connection to the Spark Connect server when connecting directly over VPC peering.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) of the certificate authority in Amazon Web Services Private CA that issued the Spark Connect server certificate.
-
#certificate_data ⇒ String
The PEM-encoded root CA certificate data.
Instance Attribute Details
#certificate_arn ⇒ String
The Amazon Resource Name (ARN) of the certificate authority in Amazon Web Services Private CA that issued the Spark Connect server certificate.
526 527 528 529 530 531 |
# File 'lib/aws-sdk-emr/types.rb', line 526 class CertificateAuthority < Struct.new( :certificate_arn, :certificate_data) SENSITIVE = [] include Aws::Structure end |
#certificate_data ⇒ String
The PEM-encoded root CA certificate data. Provide this certificate to your client’s trust store when connecting directly to the Spark Connect server over VPC peering.
526 527 528 529 530 531 |
# File 'lib/aws-sdk-emr/types.rb', line 526 class CertificateAuthority < Struct.new( :certificate_arn, :certificate_data) SENSITIVE = [] include Aws::Structure end |