Class: Aws::EMR::Types::GetSessionEndpointOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::GetSessionEndpointOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Output of the ‘GetSessionEndpoint` operation.
Constant Summary collapse
- SENSITIVE =
[:auth_token]
Instance Attribute Summary collapse
-
#auth_token ⇒ String
A time-limited authentication token used to connect to the Spark Connect endpoint.
-
#auth_token_expiration_time ⇒ Time
The time at which the authentication token expires.
-
#credentials ⇒ Types::Credentials
Username and password used to authenticate with the Spark Connect server when connecting directly over VPC peering.
-
#endpoint ⇒ String
The Spark Connect endpoint URL to use in the PySpark client.
Instance Attribute Details
#auth_token ⇒ String
A time-limited authentication token used to connect to the Spark Connect endpoint.
2395 2396 2397 2398 2399 2400 2401 2402 |
# File 'lib/aws-sdk-emr/types.rb', line 2395 class GetSessionEndpointOutput < Struct.new( :endpoint, :auth_token, :auth_token_expiration_time, :credentials) SENSITIVE = [:auth_token] include Aws::Structure end |
#auth_token_expiration_time ⇒ Time
The time at which the authentication token expires. After this time, call ‘GetSessionEndpoint` again to obtain a new token.
2395 2396 2397 2398 2399 2400 2401 2402 |
# File 'lib/aws-sdk-emr/types.rb', line 2395 class GetSessionEndpointOutput < Struct.new( :endpoint, :auth_token, :auth_token_expiration_time, :credentials) SENSITIVE = [:auth_token] include Aws::Structure end |
#credentials ⇒ Types::Credentials
Username and password used to authenticate with the Spark Connect server when connecting directly over VPC peering.
2395 2396 2397 2398 2399 2400 2401 2402 |
# File 'lib/aws-sdk-emr/types.rb', line 2395 class GetSessionEndpointOutput < Struct.new( :endpoint, :auth_token, :auth_token_expiration_time, :credentials) SENSITIVE = [:auth_token] include Aws::Structure end |
#endpoint ⇒ String
The Spark Connect endpoint URL to use in the PySpark client.
2395 2396 2397 2398 2399 2400 2401 2402 |
# File 'lib/aws-sdk-emr/types.rb', line 2395 class GetSessionEndpointOutput < Struct.new( :endpoint, :auth_token, :auth_token_expiration_time, :credentials) SENSITIVE = [:auth_token] include Aws::Structure end |