Class: Aws::EMR::Types::Instance
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::Instance
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Represents an Amazon EC2 instance provisioned as part of cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ebs_volumes ⇒ Array<Types::EbsVolume>
The list of Amazon EBS volumes that are attached to this instance.
-
#ec2_instance_id ⇒ String
The unique identifier of the instance in Amazon EC2.
-
#id ⇒ String
The unique identifier for the instance in Amazon EMR.
-
#instance_fleet_id ⇒ String
The unique identifier of the instance fleet to which an Amazon EC2 instance belongs.
-
#instance_group_id ⇒ String
The identifier of the instance group to which this instance belongs.
-
#instance_type ⇒ String
The Amazon EC2 instance type, for example ‘m3.xlarge`.
-
#market ⇒ String
The instance purchasing option.
-
#private_dns_name ⇒ String
The private DNS name of the instance.
-
#private_ip_address ⇒ String
The private IP address of the instance.
-
#public_dns_name ⇒ String
The public DNS name of the instance.
-
#public_ip_address ⇒ String
The public IP address of the instance.
-
#status ⇒ Types::InstanceStatus
The current status of the instance.
Instance Attribute Details
#ebs_volumes ⇒ Array<Types::EbsVolume>
The list of Amazon EBS volumes that are attached to this instance.
2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 |
# File 'lib/aws-sdk-emr/types.rb', line 2617 class Instance < Struct.new( :id, :ec2_instance_id, :public_dns_name, :public_ip_address, :private_dns_name, :private_ip_address, :status, :instance_group_id, :instance_fleet_id, :market, :instance_type, :ebs_volumes) SENSITIVE = [] include Aws::Structure end |
#ec2_instance_id ⇒ String
The unique identifier of the instance in Amazon EC2.
2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 |
# File 'lib/aws-sdk-emr/types.rb', line 2617 class Instance < Struct.new( :id, :ec2_instance_id, :public_dns_name, :public_ip_address, :private_dns_name, :private_ip_address, :status, :instance_group_id, :instance_fleet_id, :market, :instance_type, :ebs_volumes) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier for the instance in Amazon EMR.
2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 |
# File 'lib/aws-sdk-emr/types.rb', line 2617 class Instance < Struct.new( :id, :ec2_instance_id, :public_dns_name, :public_ip_address, :private_dns_name, :private_ip_address, :status, :instance_group_id, :instance_fleet_id, :market, :instance_type, :ebs_volumes) SENSITIVE = [] include Aws::Structure end |
#instance_fleet_id ⇒ String
The unique identifier of the instance fleet to which an Amazon EC2 instance belongs.
2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 |
# File 'lib/aws-sdk-emr/types.rb', line 2617 class Instance < Struct.new( :id, :ec2_instance_id, :public_dns_name, :public_ip_address, :private_dns_name, :private_ip_address, :status, :instance_group_id, :instance_fleet_id, :market, :instance_type, :ebs_volumes) SENSITIVE = [] include Aws::Structure end |
#instance_group_id ⇒ String
The identifier of the instance group to which this instance belongs.
2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 |
# File 'lib/aws-sdk-emr/types.rb', line 2617 class Instance < Struct.new( :id, :ec2_instance_id, :public_dns_name, :public_ip_address, :private_dns_name, :private_ip_address, :status, :instance_group_id, :instance_fleet_id, :market, :instance_type, :ebs_volumes) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The Amazon EC2 instance type, for example ‘m3.xlarge`.
2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 |
# File 'lib/aws-sdk-emr/types.rb', line 2617 class Instance < Struct.new( :id, :ec2_instance_id, :public_dns_name, :public_ip_address, :private_dns_name, :private_ip_address, :status, :instance_group_id, :instance_fleet_id, :market, :instance_type, :ebs_volumes) SENSITIVE = [] include Aws::Structure end |
#market ⇒ String
The instance purchasing option. Valid values are ‘ON_DEMAND` or `SPOT`.
2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 |
# File 'lib/aws-sdk-emr/types.rb', line 2617 class Instance < Struct.new( :id, :ec2_instance_id, :public_dns_name, :public_ip_address, :private_dns_name, :private_ip_address, :status, :instance_group_id, :instance_fleet_id, :market, :instance_type, :ebs_volumes) SENSITIVE = [] include Aws::Structure end |
#private_dns_name ⇒ String
The private DNS name of the instance.
2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 |
# File 'lib/aws-sdk-emr/types.rb', line 2617 class Instance < Struct.new( :id, :ec2_instance_id, :public_dns_name, :public_ip_address, :private_dns_name, :private_ip_address, :status, :instance_group_id, :instance_fleet_id, :market, :instance_type, :ebs_volumes) SENSITIVE = [] include Aws::Structure end |
#private_ip_address ⇒ String
The private IP address of the instance.
2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 |
# File 'lib/aws-sdk-emr/types.rb', line 2617 class Instance < Struct.new( :id, :ec2_instance_id, :public_dns_name, :public_ip_address, :private_dns_name, :private_ip_address, :status, :instance_group_id, :instance_fleet_id, :market, :instance_type, :ebs_volumes) SENSITIVE = [] include Aws::Structure end |
#public_dns_name ⇒ String
The public DNS name of the instance.
2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 |
# File 'lib/aws-sdk-emr/types.rb', line 2617 class Instance < Struct.new( :id, :ec2_instance_id, :public_dns_name, :public_ip_address, :private_dns_name, :private_ip_address, :status, :instance_group_id, :instance_fleet_id, :market, :instance_type, :ebs_volumes) SENSITIVE = [] include Aws::Structure end |
#public_ip_address ⇒ String
The public IP address of the instance.
2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 |
# File 'lib/aws-sdk-emr/types.rb', line 2617 class Instance < Struct.new( :id, :ec2_instance_id, :public_dns_name, :public_ip_address, :private_dns_name, :private_ip_address, :status, :instance_group_id, :instance_fleet_id, :market, :instance_type, :ebs_volumes) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::InstanceStatus
The current status of the instance.
2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 |
# File 'lib/aws-sdk-emr/types.rb', line 2617 class Instance < Struct.new( :id, :ec2_instance_id, :public_dns_name, :public_ip_address, :private_dns_name, :private_ip_address, :status, :instance_group_id, :instance_fleet_id, :market, :instance_type, :ebs_volumes) SENSITIVE = [] include Aws::Structure end |