Class: Aws::EMR::Types::ModifyClusterInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::ModifyClusterInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
The unique identifier of the cluster.
-
#extended_support ⇒ Boolean
Reserved.
-
#step_concurrency_level ⇒ Integer
The number of steps that can be executed concurrently.
Instance Attribute Details
#cluster_id ⇒ String
The unique identifier of the cluster.
4934 4935 4936 4937 4938 4939 4940 |
# File 'lib/aws-sdk-emr/types.rb', line 4934 class ModifyClusterInput < Struct.new( :cluster_id, :step_concurrency_level, :extended_support) SENSITIVE = [] include Aws::Structure end |
#extended_support ⇒ Boolean
Reserved.
4934 4935 4936 4937 4938 4939 4940 |
# File 'lib/aws-sdk-emr/types.rb', line 4934 class ModifyClusterInput < Struct.new( :cluster_id, :step_concurrency_level, :extended_support) SENSITIVE = [] include Aws::Structure end |
#step_concurrency_level ⇒ Integer
The number of steps that can be executed concurrently. You can
specify a minimum of 1 step and a maximum of 256 steps. We recommend
that you do not change this parameter while steps are running or the
ActionOnFailure setting may not behave as expected. For more
information see Step$ActionOnFailure.
4934 4935 4936 4937 4938 4939 4940 |
# File 'lib/aws-sdk-emr/types.rb', line 4934 class ModifyClusterInput < Struct.new( :cluster_id, :step_concurrency_level, :extended_support) SENSITIVE = [] include Aws::Structure end |