Class: Aws::EMR::Types::ScalingRule

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

A scale-in or scale-out rule that defines scaling activity, including the CloudWatch metric alarm that triggers activity, how Amazon EC2 instances are added or removed, and the periodicity of adjustments. The automatic scaling policy for an instance group can comprise one or more automatic scaling rules.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionTypes::ScalingAction

The conditions that trigger an automatic scaling activity.



6382
6383
6384
6385
6386
6387
6388
6389
# File 'lib/aws-sdk-emr/types.rb', line 6382

class ScalingRule < Struct.new(
  :name,
  :description,
  :action,
  :trigger)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A friendly, more verbose description of the automatic scaling rule.

Returns:

  • (String)


6382
6383
6384
6385
6386
6387
6388
6389
# File 'lib/aws-sdk-emr/types.rb', line 6382

class ScalingRule < Struct.new(
  :name,
  :description,
  :action,
  :trigger)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name used to identify an automatic scaling rule. Rule names must be unique within a scaling policy.

Returns:

  • (String)


6382
6383
6384
6385
6386
6387
6388
6389
# File 'lib/aws-sdk-emr/types.rb', line 6382

class ScalingRule < Struct.new(
  :name,
  :description,
  :action,
  :trigger)
  SENSITIVE = []
  include Aws::Structure
end

#triggerTypes::ScalingTrigger

The CloudWatch alarm definition that determines when automatic scaling activity is triggered.



6382
6383
6384
6385
6386
6387
6388
6389
# File 'lib/aws-sdk-emr/types.rb', line 6382

class ScalingRule < Struct.new(
  :name,
  :description,
  :action,
  :trigger)
  SENSITIVE = []
  include Aws::Structure
end