Class: Aws::EMR::Types::Session

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

Detailed information about a Spark Connect session.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The Amazon Web Services account ID that owns the session.

Returns:

  • (String)


6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the session.

Returns:

  • (String)


6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_authorityTypes::CertificateAuthority

The certificate authority used to establish an mTLS connection to the Spark Connect server when connecting directly over VPC peering.



6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_idString

The ID of the cluster that the session belongs to.

Returns:

  • (String)


6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time that the session was created.

Returns:

  • (Time)


6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ended_atTime

The date and time that the session was terminated or failed.

Returns:

  • (Time)


6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#engine_configurationsArray<Types::Configuration>

The configuration overrides for the session. Only runtime configuration overrides are supported.

Returns:



6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The execution role ARN for the session. Amazon EMR uses this role to access Amazon Web Services resources on your behalf during session execution.

Returns:

  • (String)


6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the session.

Returns:

  • (String)


6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idle_sinceTime

The date and time that the session last entered the ‘IDLE` state.

Returns:

  • (Time)


6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#monitoring_configurationTypes::SessionMonitoringConfiguration

The monitoring configuration for the session.



6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the session, if one was provided at creation time.

Returns:

  • (String)


6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#release_labelString

The Amazon EMR release label of the cluster that the session is running on.

Returns:

  • (String)


6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#server_urlString

The Spark Connect server URL for the session. Use this URL with the ‘Credentials` returned by `GetSessionEndpoint` to connect directly to the session over VPC peering.

Returns:

  • (String)


6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#session_idle_timeout_in_minutesInteger

The idle timeout, in minutes. If the session is idle for this duration, Amazon EMR automatically terminates it.

Returns:

  • (Integer)


6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The date and time that the session entered the ‘STARTED` state.

Returns:

  • (Time)


6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the session. Valid values are ‘SUBMITTED`, `STARTING`, `STARTED`, `IDLE`, `BUSY`, `TERMINATING`, `TERMINATED`, and `FAILED`.

Returns:

  • (String)


6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#state_change_reasonString

A human-readable message describing the most recent state change.

Returns:

  • (String)


6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags associated with the session.

Returns:



6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time that the session was last updated.

Returns:

  • (Time)


6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
6554
6555
6556
6557
6558
6559
6560
6561
6562
6563
6564
# File 'lib/aws-sdk-emr/types.rb', line 6541

class Session < Struct.new(
  :id,
  :cluster_id,
  :name,
  :arn,
  :state,
  :state_change_reason,
  :release_label,
  :execution_role_arn,
  :account_id,
  :created_at,
  :updated_at,
  :started_at,
  :ended_at,
  :idle_since,
  :engine_configurations,
  :monitoring_configuration,
  :session_idle_timeout_in_minutes,
  :certificate_authority,
  :server_url,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end