Class: Aws::EMR::Types::Session
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::Session
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Detailed information about a Spark Connect session.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Amazon Web Services account ID that owns the session.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the session.
-
#certificate_authority ⇒ Types::CertificateAuthority
The certificate authority used to establish an mTLS connection to the Spark Connect server when connecting directly over VPC peering.
-
#cluster_id ⇒ String
The ID of the cluster that the session belongs to.
-
#created_at ⇒ Time
The date and time that the session was created.
-
#ended_at ⇒ Time
The date and time that the session was terminated or failed.
-
#engine_configurations ⇒ Array<Types::Configuration>
The configuration overrides for the session.
-
#execution_role_arn ⇒ String
The execution role ARN for the session.
-
#id ⇒ String
The ID of the session.
-
#idle_since ⇒ Time
The date and time that the session last entered the ‘IDLE` state.
-
#monitoring_configuration ⇒ Types::SessionMonitoringConfiguration
The monitoring configuration for the session.
-
#name ⇒ String
The name of the session, if one was provided at creation time.
-
#release_label ⇒ String
The Amazon EMR release label of the cluster that the session is running on.
-
#server_url ⇒ String
The Spark Connect server URL for the session.
-
#session_idle_timeout_in_minutes ⇒ Integer
The idle timeout, in minutes.
-
#started_at ⇒ Time
The date and time that the session entered the ‘STARTED` state.
-
#state ⇒ String
The current state of the session.
-
#state_change_reason ⇒ String
A human-readable message describing the most recent state change.
-
#tags ⇒ Array<Types::Tag>
The tags associated with the session.
-
#updated_at ⇒ Time
The date and time that the session was last updated.
Instance Attribute Details
#account_id ⇒ String
The Amazon Web Services account ID that owns the session.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the session.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#certificate_authority ⇒ Types::CertificateAuthority
The certificate authority used to establish an mTLS connection to the Spark Connect server when connecting directly over VPC peering.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#cluster_id ⇒ String
The ID of the cluster that the session belongs to.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the session was created.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#ended_at ⇒ Time
The date and time that the session was terminated or failed.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#engine_configurations ⇒ Array<Types::Configuration>
The configuration overrides for the session. Only runtime configuration overrides are supported.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The execution role ARN for the session. Amazon EMR uses this role to access Amazon Web Services resources on your behalf during session execution.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the session.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#idle_since ⇒ Time
The date and time that the session last entered the ‘IDLE` state.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#monitoring_configuration ⇒ Types::SessionMonitoringConfiguration
The monitoring configuration for the session.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the session, if one was provided at creation time.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#release_label ⇒ String
The Amazon EMR release label of the cluster that the session is running on.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#server_url ⇒ String
The Spark Connect server URL for the session. Use this URL with the ‘Credentials` returned by `GetSessionEndpoint` to connect directly to the session over VPC peering.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#session_idle_timeout_in_minutes ⇒ Integer
The idle timeout, in minutes. If the session is idle for this duration, Amazon EMR automatically terminates it.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The date and time that the session entered the ‘STARTED` state.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the session. Valid values are ‘SUBMITTED`, `STARTING`, `STARTED`, `IDLE`, `BUSY`, `TERMINATING`, `TERMINATED`, and `FAILED`.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#state_change_reason ⇒ String
A human-readable message describing the most recent state change.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags associated with the session.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time that the session was last updated.
6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-emr/types.rb', line 6541 class Session < Struct.new( :id, :cluster_id, :name, :arn, :state, :state_change_reason, :release_label, :execution_role_arn, :account_id, :created_at, :updated_at, :started_at, :ended_at, :idle_since, :engine_configurations, :monitoring_configuration, :session_idle_timeout_in_minutes, :certificate_authority, :server_url, :tags) SENSITIVE = [] include Aws::Structure end |