Class: Aws::EMR::Types::SessionCloudWatchLoggingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::SessionCloudWatchLoggingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
The CloudWatch Logs configuration for a session.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Whether CloudWatch Logs is enabled for the session.
-
#encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt the logs published to CloudWatch Logs.
-
#log_group ⇒ String
The name of the log group where session logs are published.
-
#log_stream_name_prefix ⇒ String
The prefix applied to the log stream name where session logs are published.
-
#log_types ⇒ Hash<String,Array<String>>
A map of log component names (for example, ‘SPARK_DRIVER`, `SPARK_EXECUTOR`) to the list of log types to publish for that component (for example, `stdout`, `stderr`).
Instance Attribute Details
#enabled ⇒ Boolean
Whether CloudWatch Logs is enabled for the session.
6594 6595 6596 6597 6598 6599 6600 6601 6602 |
# File 'lib/aws-sdk-emr/types.rb', line 6594 class SessionCloudWatchLoggingConfiguration < Struct.new( :enabled, :log_group, :log_stream_name_prefix, :encryption_key_arn, :log_types) SENSITIVE = [] include Aws::Structure end |
#encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt the logs published to CloudWatch Logs.
6594 6595 6596 6597 6598 6599 6600 6601 6602 |
# File 'lib/aws-sdk-emr/types.rb', line 6594 class SessionCloudWatchLoggingConfiguration < Struct.new( :enabled, :log_group, :log_stream_name_prefix, :encryption_key_arn, :log_types) SENSITIVE = [] include Aws::Structure end |
#log_group ⇒ String
The name of the log group where session logs are published.
6594 6595 6596 6597 6598 6599 6600 6601 6602 |
# File 'lib/aws-sdk-emr/types.rb', line 6594 class SessionCloudWatchLoggingConfiguration < Struct.new( :enabled, :log_group, :log_stream_name_prefix, :encryption_key_arn, :log_types) SENSITIVE = [] include Aws::Structure end |
#log_stream_name_prefix ⇒ String
The prefix applied to the log stream name where session logs are published.
6594 6595 6596 6597 6598 6599 6600 6601 6602 |
# File 'lib/aws-sdk-emr/types.rb', line 6594 class SessionCloudWatchLoggingConfiguration < Struct.new( :enabled, :log_group, :log_stream_name_prefix, :encryption_key_arn, :log_types) SENSITIVE = [] include Aws::Structure end |
#log_types ⇒ Hash<String,Array<String>>
A map of log component names (for example, ‘SPARK_DRIVER`, `SPARK_EXECUTOR`) to the list of log types to publish for that component (for example, `stdout`, `stderr`).
6594 6595 6596 6597 6598 6599 6600 6601 6602 |
# File 'lib/aws-sdk-emr/types.rb', line 6594 class SessionCloudWatchLoggingConfiguration < Struct.new( :enabled, :log_group, :log_stream_name_prefix, :encryption_key_arn, :log_types) SENSITIVE = [] include Aws::Structure end |