Class: Aws::EMR::Types::SessionS3LoggingConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

The Amazon S3 logging configuration for a session.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

Whether Amazon S3 logging is enabled for the session.

Returns:

  • (Boolean)


6776
6777
6778
6779
6780
6781
6782
6783
# File 'lib/aws-sdk-emr/types.rb', line 6776

class SessionS3LoggingConfiguration < Struct.new(
  :enabled,
  :log_uri,
  :encryption_key_arn,
  :log_types)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_key_arnString

The Amazon Resource Name (ARN) of the KMS key used to encrypt logs published to Amazon S3.

Returns:

  • (String)


6776
6777
6778
6779
6780
6781
6782
6783
# File 'lib/aws-sdk-emr/types.rb', line 6776

class SessionS3LoggingConfiguration < Struct.new(
  :enabled,
  :log_uri,
  :encryption_key_arn,
  :log_types)
  SENSITIVE = []
  include Aws::Structure
end

#log_typesHash<String,Array<String>>

A map of log component names (for example, ‘SPARK_DRIVER`, `SPARK_EXECUTOR`) to the list of log types to publish for that component (for example, `stdout`, `stderr`).

Returns:

  • (Hash<String,Array<String>>)


6776
6777
6778
6779
6780
6781
6782
6783
# File 'lib/aws-sdk-emr/types.rb', line 6776

class SessionS3LoggingConfiguration < Struct.new(
  :enabled,
  :log_uri,
  :encryption_key_arn,
  :log_types)
  SENSITIVE = []
  include Aws::Structure
end

#log_uriString

The Amazon S3 destination URI where session logs are published.

Returns:

  • (String)


6776
6777
6778
6779
6780
6781
6782
6783
# File 'lib/aws-sdk-emr/types.rb', line 6776

class SessionS3LoggingConfiguration < Struct.new(
  :enabled,
  :log_uri,
  :encryption_key_arn,
  :log_types)
  SENSITIVE = []
  include Aws::Structure
end