Class: Aws::EMR::Types::SetUnhealthyNodeReplacementInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_flow_idsArray<String>

The list of strings that uniquely identify the clusters for which to turn on unhealthy node replacement. You can get these identifiers by running the RunJobFlow or the DescribeJobFlows operations.

Returns:

  • (Array<String>)


6846
6847
6848
6849
6850
6851
# File 'lib/aws-sdk-emr/types.rb', line 6846

class SetUnhealthyNodeReplacementInput < Struct.new(
  :job_flow_ids,
  :unhealthy_node_replacement)
  SENSITIVE = []
  include Aws::Structure
end

#unhealthy_node_replacementBoolean

Indicates whether to turn on or turn off graceful unhealthy node replacement.

Returns:

  • (Boolean)


6846
6847
6848
6849
6850
6851
# File 'lib/aws-sdk-emr/types.rb', line 6846

class SetUnhealthyNodeReplacementInput < Struct.new(
  :job_flow_ids,
  :unhealthy_node_replacement)
  SENSITIVE = []
  include Aws::Structure
end