Class: Aws::EMR::Types::SetUnhealthyNodeReplacementInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::SetUnhealthyNodeReplacementInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_flow_ids ⇒ Array<String>
The list of strings that uniquely identify the clusters for which to turn on unhealthy node replacement.
-
#unhealthy_node_replacement ⇒ Boolean
Indicates whether to turn on or turn off graceful unhealthy node replacement.
Instance Attribute Details
#job_flow_ids ⇒ Array<String>
The list of strings that uniquely identify the clusters for which to turn on unhealthy node replacement. You can get these identifiers by running the RunJobFlow or the DescribeJobFlows operations.
6425 6426 6427 6428 6429 6430 |
# File 'lib/aws-sdk-emr/types.rb', line 6425 class SetUnhealthyNodeReplacementInput < Struct.new( :job_flow_ids, :unhealthy_node_replacement) SENSITIVE = [] include Aws::Structure end |
#unhealthy_node_replacement ⇒ Boolean
Indicates whether to turn on or turn off graceful unhealthy node replacement.
6425 6426 6427 6428 6429 6430 |
# File 'lib/aws-sdk-emr/types.rb', line 6425 class SetUnhealthyNodeReplacementInput < Struct.new( :job_flow_ids, :unhealthy_node_replacement) SENSITIVE = [] include Aws::Structure end |