Class: Aws::EMR::Types::SetVisibleToAllUsersInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::SetVisibleToAllUsersInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
The input to the SetVisibleToAllUsers action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_flow_ids ⇒ Array<String>
The unique identifier of the job flow (cluster).
-
#visible_to_all_users ⇒ Boolean
A value of ‘true` indicates that an IAM principal in the Amazon Web Services account can perform Amazon EMR actions on the cluster that the IAM policies attached to the principal allow.
Instance Attribute Details
#job_flow_ids ⇒ Array<String>
The unique identifier of the job flow (cluster).
6870 6871 6872 6873 6874 6875 |
# File 'lib/aws-sdk-emr/types.rb', line 6870 class SetVisibleToAllUsersInput < Struct.new( :job_flow_ids, :visible_to_all_users) SENSITIVE = [] include Aws::Structure end |
#visible_to_all_users ⇒ Boolean
A value of ‘true` indicates that an IAM principal in the Amazon Web Services account can perform Amazon EMR actions on the cluster that the IAM policies attached to the principal allow. A value of `false` indicates that only the IAM principal that created the cluster and the Amazon Web Services root user can perform Amazon EMR actions on the cluster.
6870 6871 6872 6873 6874 6875 |
# File 'lib/aws-sdk-emr/types.rb', line 6870 class SetVisibleToAllUsersInput < Struct.new( :job_flow_ids, :visible_to_all_users) SENSITIVE = [] include Aws::Structure end |