Class: Aws::EMR::Types::StartSessionOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emr/types.rb

Overview

Output of the ‘StartSession` operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The Amazon Web Services account ID that owns the session.

Returns:

  • (String)


7263
7264
7265
7266
7267
7268
7269
7270
7271
# File 'lib/aws-sdk-emr/types.rb', line 7263

class StartSessionOutput < Struct.new(
  :id,
  :cluster_id,
  :arn,
  :account_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The output contains the ARN of the session.

Returns:

  • (String)


7263
7264
7265
7266
7267
7268
7269
7270
7271
# File 'lib/aws-sdk-emr/types.rb', line 7263

class StartSessionOutput < Struct.new(
  :id,
  :cluster_id,
  :arn,
  :account_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_idString

The ID of the cluster that the session was started on.

Returns:

  • (String)


7263
7264
7265
7266
7267
7268
7269
7270
7271
# File 'lib/aws-sdk-emr/types.rb', line 7263

class StartSessionOutput < Struct.new(
  :id,
  :cluster_id,
  :arn,
  :account_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The output contains the ID of the session.

Returns:

  • (String)


7263
7264
7265
7266
7267
7268
7269
7270
7271
# File 'lib/aws-sdk-emr/types.rb', line 7263

class StartSessionOutput < Struct.new(
  :id,
  :cluster_id,
  :arn,
  :account_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the session at the time the request returned. When a session is first created, it enters the ‘SUBMITTED` state.

Returns:

  • (String)


7263
7264
7265
7266
7267
7268
7269
7270
7271
# File 'lib/aws-sdk-emr/types.rb', line 7263

class StartSessionOutput < Struct.new(
  :id,
  :cluster_id,
  :arn,
  :account_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end