Class: Aws::EMR::Types::SupportedInstanceType
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::SupportedInstanceType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
An instance type that the specified Amazon EMR release supports.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#architecture ⇒ String
The CPU architecture, for example ‘X86_64` or `AARCH64`.
-
#ebs_optimized_available ⇒ Boolean
Indicates whether the ‘SupportedInstanceType` supports Amazon EBS optimization.
-
#ebs_optimized_by_default ⇒ Boolean
Indicates whether the ‘SupportedInstanceType` uses Amazon EBS optimization by default.
-
#ebs_storage_only ⇒ Boolean
Indicates whether the ‘SupportedInstanceType` only supports Amazon EBS.
-
#instance_family_id ⇒ String
The Amazon EC2 family and generation for the ‘SupportedInstanceType`.
-
#is_64_bits_only ⇒ Boolean
Indicates whether the ‘SupportedInstanceType` only supports 64-bit architecture.
-
#memory_gb ⇒ Float
The amount of memory that is available to Amazon EMR from the ‘SupportedInstanceType`.
-
#number_of_disks ⇒ Integer
Number of disks for the ‘SupportedInstanceType`.
-
#storage_gb ⇒ Integer
‘StorageGB` represents the storage capacity of the `SupportedInstanceType`.
-
#type ⇒ String
The [Amazon EC2 instance type], for example ‘m5.xlarge`, of the `SupportedInstanceType`.
-
#vcpu ⇒ Integer
The number of vCPUs available for the ‘SupportedInstanceType`.
Instance Attribute Details
#architecture ⇒ String
The CPU architecture, for example ‘X86_64` or `AARCH64`.
7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 |
# File 'lib/aws-sdk-emr/types.rb', line 7273 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#ebs_optimized_available ⇒ Boolean
Indicates whether the ‘SupportedInstanceType` supports Amazon EBS optimization.
7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 |
# File 'lib/aws-sdk-emr/types.rb', line 7273 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#ebs_optimized_by_default ⇒ Boolean
Indicates whether the ‘SupportedInstanceType` uses Amazon EBS optimization by default.
7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 |
# File 'lib/aws-sdk-emr/types.rb', line 7273 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#ebs_storage_only ⇒ Boolean
Indicates whether the ‘SupportedInstanceType` only supports Amazon EBS.
7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 |
# File 'lib/aws-sdk-emr/types.rb', line 7273 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#instance_family_id ⇒ String
The Amazon EC2 family and generation for the ‘SupportedInstanceType`.
7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 |
# File 'lib/aws-sdk-emr/types.rb', line 7273 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#is_64_bits_only ⇒ Boolean
Indicates whether the ‘SupportedInstanceType` only supports 64-bit architecture.
7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 |
# File 'lib/aws-sdk-emr/types.rb', line 7273 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#memory_gb ⇒ Float
The amount of memory that is available to Amazon EMR from the ‘SupportedInstanceType`. The kernel and hypervisor software consume some memory, so this value might be lower than the overall memory for the instance type.
7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 |
# File 'lib/aws-sdk-emr/types.rb', line 7273 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#number_of_disks ⇒ Integer
Number of disks for the ‘SupportedInstanceType`. This value is `0` for Amazon EBS-only instance types.
7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 |
# File 'lib/aws-sdk-emr/types.rb', line 7273 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#storage_gb ⇒ Integer
‘StorageGB` represents the storage capacity of the `SupportedInstanceType`. This value is `0` for Amazon EBS-only instance types.
7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 |
# File 'lib/aws-sdk-emr/types.rb', line 7273 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The [Amazon EC2 instance type], for example ‘m5.xlarge`, of the `SupportedInstanceType`.
7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 |
# File 'lib/aws-sdk-emr/types.rb', line 7273 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#vcpu ⇒ Integer
The number of vCPUs available for the ‘SupportedInstanceType`.
7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 7287 |
# File 'lib/aws-sdk-emr/types.rb', line 7273 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |