Class: Aws::EMR::Types::SupportedInstanceType
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::SupportedInstanceType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
An instance type that the specified Amazon EMR release supports.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#architecture ⇒ String
The CPU architecture, for example
X86_64orAARCH64. -
#ebs_optimized_available ⇒ Boolean
Indicates whether the
SupportedInstanceTypesupports Amazon EBS optimization. -
#ebs_optimized_by_default ⇒ Boolean
Indicates whether the
SupportedInstanceTypeuses Amazon EBS optimization by default. -
#ebs_storage_only ⇒ Boolean
Indicates whether the
SupportedInstanceTypeonly supports Amazon EBS. -
#instance_family_id ⇒ String
The Amazon EC2 family and generation for the
SupportedInstanceType. -
#is_64_bits_only ⇒ Boolean
Indicates whether the
SupportedInstanceTypeonly supports 64-bit architecture. -
#memory_gb ⇒ Float
The amount of memory that is available to Amazon EMR from the
SupportedInstanceType. -
#number_of_disks ⇒ Integer
Number of disks for the
SupportedInstanceType. -
#storage_gb ⇒ Integer
StorageGBrepresents the storage capacity of theSupportedInstanceType. -
#type ⇒ String
The [Amazon EC2 instance type][1], for example
m5.xlarge, of theSupportedInstanceType. -
#vcpu ⇒ Integer
The number of vCPUs available for the
SupportedInstanceType.
Instance Attribute Details
#architecture ⇒ String
The CPU architecture, for example X86_64 or AARCH64.
7337 7338 7339 7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 7351 |
# File 'lib/aws-sdk-emr/types.rb', line 7337 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#ebs_optimized_available ⇒ Boolean
Indicates whether the SupportedInstanceType supports Amazon EBS optimization.
7337 7338 7339 7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 7351 |
# File 'lib/aws-sdk-emr/types.rb', line 7337 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#ebs_optimized_by_default ⇒ Boolean
Indicates whether the SupportedInstanceType uses Amazon EBS optimization by default.
7337 7338 7339 7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 7351 |
# File 'lib/aws-sdk-emr/types.rb', line 7337 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#ebs_storage_only ⇒ Boolean
Indicates whether the SupportedInstanceType only supports Amazon EBS.
7337 7338 7339 7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 7351 |
# File 'lib/aws-sdk-emr/types.rb', line 7337 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#instance_family_id ⇒ String
The Amazon EC2 family and generation for the SupportedInstanceType.
7337 7338 7339 7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 7351 |
# File 'lib/aws-sdk-emr/types.rb', line 7337 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#is_64_bits_only ⇒ Boolean
Indicates whether the SupportedInstanceType only supports 64-bit architecture.
7337 7338 7339 7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 7351 |
# File 'lib/aws-sdk-emr/types.rb', line 7337 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#memory_gb ⇒ Float
The amount of memory that is available to Amazon EMR from the SupportedInstanceType. The kernel and hypervisor software consume some memory, so this value might be lower than the overall memory for the instance type.
7337 7338 7339 7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 7351 |
# File 'lib/aws-sdk-emr/types.rb', line 7337 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#number_of_disks ⇒ Integer
Number of disks for the SupportedInstanceType. This value is 0 for Amazon EBS-only instance types.
7337 7338 7339 7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 7351 |
# File 'lib/aws-sdk-emr/types.rb', line 7337 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#storage_gb ⇒ Integer
StorageGB represents the storage capacity of the SupportedInstanceType. This value is 0 for Amazon EBS-only instance types.
7337 7338 7339 7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 7351 |
# File 'lib/aws-sdk-emr/types.rb', line 7337 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The [Amazon EC2 instance type][1], for example m5.xlarge, of the SupportedInstanceType.
7337 7338 7339 7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 7351 |
# File 'lib/aws-sdk-emr/types.rb', line 7337 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |
#vcpu ⇒ Integer
The number of vCPUs available for the SupportedInstanceType.
7337 7338 7339 7340 7341 7342 7343 7344 7345 7346 7347 7348 7349 7350 7351 |
# File 'lib/aws-sdk-emr/types.rb', line 7337 class SupportedInstanceType < Struct.new( :type, :memory_gb, :storage_gb, :vcpu, :is_64_bits_only, :instance_family_id, :ebs_optimized_available, :ebs_optimized_by_default, :number_of_disks, :ebs_storage_only, :architecture) SENSITIVE = [] include Aws::Structure end |