Class: Aws::EMR::Types::UpdateStudioInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMR::Types::UpdateStudioInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_s3_location ⇒ String
The Amazon S3 location to back up Workspaces and notebook files for the Amazon EMR Studio.
-
#description ⇒ String
A detailed description to assign to the Amazon EMR Studio.
-
#encryption_key_arn ⇒ String
The KMS key identifier (ARN) used to encrypt Amazon EMR Studio workspace and notebook files when backed up to Amazon S3.
-
#name ⇒ String
A descriptive name for the Amazon EMR Studio.
-
#studio_id ⇒ String
The ID of the Amazon EMR Studio to update.
-
#subnet_ids ⇒ Array<String>
A list of subnet IDs to associate with the Amazon EMR Studio.
Instance Attribute Details
#default_s3_location ⇒ String
The Amazon S3 location to back up Workspaces and notebook files for the Amazon EMR Studio.
8015 8016 8017 8018 8019 8020 8021 8022 8023 8024 |
# File 'lib/aws-sdk-emr/types.rb', line 8015 class UpdateStudioInput < Struct.new( :studio_id, :name, :description, :subnet_ids, :default_s3_location, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A detailed description to assign to the Amazon EMR Studio.
8015 8016 8017 8018 8019 8020 8021 8022 8023 8024 |
# File 'lib/aws-sdk-emr/types.rb', line 8015 class UpdateStudioInput < Struct.new( :studio_id, :name, :description, :subnet_ids, :default_s3_location, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#encryption_key_arn ⇒ String
The KMS key identifier (ARN) used to encrypt Amazon EMR Studio workspace and notebook files when backed up to Amazon S3.
8015 8016 8017 8018 8019 8020 8021 8022 8023 8024 |
# File 'lib/aws-sdk-emr/types.rb', line 8015 class UpdateStudioInput < Struct.new( :studio_id, :name, :description, :subnet_ids, :default_s3_location, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A descriptive name for the Amazon EMR Studio.
8015 8016 8017 8018 8019 8020 8021 8022 8023 8024 |
# File 'lib/aws-sdk-emr/types.rb', line 8015 class UpdateStudioInput < Struct.new( :studio_id, :name, :description, :subnet_ids, :default_s3_location, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#studio_id ⇒ String
The ID of the Amazon EMR Studio to update.
8015 8016 8017 8018 8019 8020 8021 8022 8023 8024 |
# File 'lib/aws-sdk-emr/types.rb', line 8015 class UpdateStudioInput < Struct.new( :studio_id, :name, :description, :subnet_ids, :default_s3_location, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
A list of subnet IDs to associate with the Amazon EMR Studio. The list can include new subnet IDs, but must also include all of the subnet IDs previously associated with the Studio. The list order does not matter. A Studio can have a maximum of 5 subnets. The subnets must belong to the same VPC as the Studio.
8015 8016 8017 8018 8019 8020 8021 8022 8023 8024 |
# File 'lib/aws-sdk-emr/types.rb', line 8015 class UpdateStudioInput < Struct.new( :studio_id, :name, :description, :subnet_ids, :default_s3_location, :encryption_key_arn) SENSITIVE = [] include Aws::Structure end |