Class: Aws::EMR::Waiters::StepComplete
- Inherits:
-
Object
- Object
- Aws::EMR::Waiters::StepComplete
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-emr/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ StepComplete
constructor
A new instance of StepComplete.
-
#wait(params = {}) ⇒ Types::DescribeStepOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ StepComplete
Returns a new instance of StepComplete.
192 193 |
# File 'lib/aws-sdk-emr/waiters.rb', line 192
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
230 231 232 |
# File 'lib/aws-sdk-emr/waiters.rb', line 230 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeStepOutput
Returns a response object which responds to the following methods:
- #step => Types::Step
225 |
# File 'lib/aws-sdk-emr/waiters.rb', line 225
def wait: (
|